#!/bin/sh
# Package glibc-solibs-2.11.1-i486-3
# Copyright (C) 2002, 2005  Slackware Linux, Inc.
# Copyright 2005, 2006  Patrick J. Volkerding, Sebeka, Minnesota, USA
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# Swap glibc on the fly.
#
# If we're on a running system we have to handle this _very_ carefully.  :-)
# The tricks involved here get trickier every time...

# OK, now we have to be sure of a few things.  First, you do have a 2.6
# kernel running, right?

if [ -r /proc/ksyms ]; then
  echo "FATAL: you need to be running a 2.6.x kernel in order to upgrade"
  echo "to this version of glibc."
  echo
  sleep 999
  exit 1
fi

# Next, stop using the /lib/ntpl libraries.  These are now obsolete and
# will break the installation if present:
if [ -d lib/tls ]; then
  mkdir -p lib/obsolete
  mv lib/tls lib/obsolete
fi
if [ -x sbin/ldconfig ]; then
  sbin/ldconfig -r .
fi

# Install NPTL glibc libraries:
if [ -x /sbin/ldconfig -a -d lib/incoming ]; then # swap on the fly
  # First create copies of the incoming libraries:
  ( cd lib/incoming
    for file in * ; do
      if [ ! -r ../${file}.incoming ]; then
        cp -a $file ../${file}.incoming
      fi
    done
  )
  # Then switch to them all at once:
  /sbin/ldconfig -l lib/*.incoming 2> /dev/null
  # Finally, rename them and clean up:
  ( cd lib
    for file in *.incoming ; do
      rm -f `basename $file .incoming`
      cp -a $file `basename $file .incoming`
      /sbin/ldconfig -l `basename $file .incoming`
      rm -f $file
    done
  )
else # no ldconfig?  Good, it's safe to just jam it on home (and make links below):
  ( cd lib/incoming
    for file in * ; do
      cp -a $file ..
    done
  )
fi
# Now, get rid of the temporary directory:
rm -rf lib/incoming
# Done installing NPTL glibc libraries.

# Handle config files:
config() {
  NEW="$1"
  OLD="$(dirname $NEW)/$(basename $NEW .new)"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}
# Clearly you already decided this issue.  :-)

# In case there's no ldconfig, make the links manually:
if [ ! -x /sbin/ldconfig ]; then
( cd lib ; rm -rf libnss_nis.so.2 )
( cd lib ; ln -sf libnss_nis-2.11.1.so libnss_nis.so.2 )
( cd lib ; rm -rf libm.so.6 )
( cd lib ; ln -sf libm-2.11.1.so libm.so.6 )
( cd lib ; rm -rf libnss_files.so.2 )
( cd lib ; ln -sf libnss_files-2.11.1.so libnss_files.so.2 )
( cd lib ; rm -rf libresolv.so.2 )
( cd lib ; ln -sf libresolv-2.11.1.so libresolv.so.2 )
( cd lib ; rm -rf libnsl.so.1 )
( cd lib ; ln -sf libnsl-2.11.1.so libnsl.so.1 )
( cd lib ; rm -rf libutil.so.1 )
( cd lib ; ln -sf libutil-2.11.1.so libutil.so.1 )
( cd lib ; rm -rf libnss_compat.so.2 )
( cd lib ; ln -sf libnss_compat-2.11.1.so libnss_compat.so.2 )
( cd lib ; rm -rf libthread_db.so.1 )
( cd lib ; ln -sf libthread_db-1.0.so libthread_db.so.1 )
( cd lib ; rm -rf libnss_hesiod.so.2 )
( cd lib ; ln -sf libnss_hesiod-2.11.1.so libnss_hesiod.so.2 )
( cd lib ; rm -rf libanl.so.1 )
( cd lib ; ln -sf libanl-2.11.1.so libanl.so.1 )
( cd lib ; rm -rf libcrypt.so.1 )
( cd lib ; ln -sf libcrypt-2.11.1.so libcrypt.so.1 )
( cd lib ; rm -rf libBrokenLocale.so.1 )
( cd lib ; ln -sf libBrokenLocale-2.11.1.so libBrokenLocale.so.1 )
( cd lib ; rm -rf ld-linux.so.2 )
( cd lib ; ln -sf ld-2.11.1.so ld-linux.so.2 )
( cd lib ; rm -rf libdl.so.2 )
( cd lib ; ln -sf libdl-2.11.1.so libdl.so.2 )
( cd lib ; rm -rf libnss_dns.so.2 )
( cd lib ; ln -sf libnss_dns-2.11.1.so libnss_dns.so.2 )
( cd lib ; rm -rf libpthread.so.0 )
( cd lib ; ln -sf libpthread-2.11.1.so libpthread.so.0 )
( cd lib ; rm -rf libnss_nisplus.so.2 )
( cd lib ; ln -sf libnss_nisplus-2.11.1.so libnss_nisplus.so.2 )
( cd lib ; rm -rf libc.so.6 )
( cd lib ; ln -sf libc-2.11.1.so libc.so.6 )
( cd lib ; rm -rf librt.so.1 )
( cd lib ; ln -sf librt-2.11.1.so librt.so.1 )
fi
# Package aaa_elflibs-13.1-i486-1
( cd usr/lib ; rm -rf libcurl.so.3 )
( cd usr/lib ; ln -sf libcurl.so.3.0.0 libcurl.so.3 )
( cd usr/lib ; rm -rf libpcreposix.so.0 )
( cd usr/lib ; ln -sf libpcreposix.so.0.0.0 libpcreposix.so.0 )
( cd usr/lib ; rm -rf libvga.so.1 )
( cd usr/lib ; ln -sf libvga.so.1.9.25 libvga.so.1 )
( cd usr/lib ; rm -rf libreadline.so.5 )
( cd usr/lib ; ln -sf libreadline.so.5.2 libreadline.so.5 )
( cd usr/lib ; rm -rf libusb-1.0.so.0 )
( cd usr/lib ; ln -sf libusb-1.0.so.0.0.0 libusb-1.0.so.0 )
( cd usr/lib ; rm -rf libpanel.so.5 )
( cd usr/lib ; ln -sf libpanel.so.5.7 libpanel.so.5 )
( cd usr/lib ; rm -rf libhistory.so.5 )
( cd usr/lib ; ln -sf libhistory.so.5.2 libhistory.so.5 )
( cd usr/lib ; rm -rf libvgagl.so.1 )
( cd usr/lib ; ln -sf libvgagl.so.1.9.25 libvgagl.so.1 )
( cd usr/lib ; rm -rf libgmodule-2.0.so.0 )
( cd usr/lib ; ln -sf libgmodule-2.0.so.0.2200.5 libgmodule-2.0.so.0 )
( cd usr/lib ; rm -rf libjpeg.so.62 )
( cd usr/lib ; ln -sf libjpeg.so.62.0.0 libjpeg.so.62 )
( cd usr/lib ; rm -rf libexpat.so.0 )
( cd usr/lib ; ln -sf libexpat.so.0.5.0 libexpat.so.0 )
( cd usr/lib ; rm -rf liblber-2.3.so.0 )
( cd usr/lib ; ln -sf liblber-2.3.so.0.2.31 liblber-2.3.so.0 )
( cd usr/lib ; rm -rf libmp.so.3 )
( cd usr/lib ; ln -sf libmp.so.3.1.21 libmp.so.3 )
( cd usr/lib ; rm -rf libpng.so.14 )
( cd usr/lib ; ln -sf libpng14.so.14 libpng.so.14 )
( cd usr/lib ; rm -rf libltdl.so.3 )
( cd usr/lib ; ln -sf libltdl.so.3.1.6 libltdl.so.3 )
( cd usr/lib ; rm -rf libformw.so.5 )
( cd usr/lib ; ln -sf libformw.so.5.7 libformw.so.5 )
( cd usr/lib ; rm -rf libasound.so.2 )
( cd usr/lib ; ln -sf libasound.so.2.0.0 libasound.so.2 )
( cd usr/lib ; rm -rf libhistory.so.4 )
( cd usr/lib ; ln -sf libhistory.so.4.3 libhistory.so.4 )
( cd usr/lib ; rm -rf libreadline.so.4 )
( cd usr/lib ; ln -sf libreadline.so.4.3 libreadline.so.4 )
( cd usr/lib ; rm -rf libcurl.so.4 )
( cd usr/lib ; ln -sf libcurl.so.4.2.0 libcurl.so.4 )
( cd usr/lib ; rm -rf libslang.so.1 )
( cd usr/lib ; ln -sf libslang.so.1.4.9 libslang.so.1 )
( cd usr/lib ; rm -rf libmm.so.14 )
( cd usr/lib ; ln -sf libmm.so.14.0.22 libmm.so.14 )
( cd usr/lib ; rm -rf libmenuw.so.5 )
( cd usr/lib ; ln -sf libmenuw.so.5.7 libmenuw.so.5 )
( cd usr/lib ; rm -rf libgdbm.so.3 )
( cd usr/lib ; ln -sf libgdbm.so.3.0.0 libgdbm.so.3 )
( cd usr/lib ; rm -rf libgmpxx.so.3 )
( cd usr/lib ; ln -sf libgmpxx.so.3.1.1 libgmpxx.so.3 )
( cd usr/lib ; rm -rf libglib-2.0.so.0 )
( cd usr/lib ; ln -sf libglib-2.0.so.0.2200.5 libglib-2.0.so.0 )
( cd usr/lib ; rm -rf libgmp.so.3 )
( cd usr/lib ; ln -sf libgmp.so.3.4.4 libgmp.so.3 )
( cd usr/lib ; rm -rf libexpat.so.1 )
( cd usr/lib ; ln -sf libexpat.so.1.5.2 libexpat.so.1 )
( cd usr/lib ; rm -rf libgobject-2.0.so.0 )
( cd usr/lib ; ln -sf libgobject-2.0.so.0.2200.5 libgobject-2.0.so.0 )
( cd usr/lib ; rm -rf libgmpxx.so.4 )
( cd usr/lib ; ln -sf libgmpxx.so.4.2.1 libgmpxx.so.4 )
( cd usr/lib ; rm -rf libslang.so.2 )
( cd usr/lib ; ln -sf libslang.so.2.2.2 libslang.so.2 )
( cd usr/lib ; rm -rf libform.so.5 )
( cd usr/lib ; ln -sf libform.so.5.7 libform.so.5 )
( cd usr/lib ; rm -rf libpng14.so.14 )
( cd usr/lib ; ln -sf libpng14.so.14.2.0 libpng14.so.14 )
( cd usr/lib ; rm -rf libpng12.so.0 )
( cd usr/lib ; ln -sf libpng12.so.0.43.0 libpng12.so.0 )
( cd usr/lib ; rm -rf libz.so.1 )
( cd usr/lib ; ln -sf libz.so.1.2.3 libz.so.1 )
( cd usr/lib ; rm -rf libpanelw.so.5 )
( cd usr/lib ; ln -sf libpanelw.so.5.7 libpanelw.so.5 )
( cd usr/lib ; rm -rf libpng.so.3 )
( cd usr/lib ; ln -sf libpng.so.3.43.0 libpng.so.3 )
( cd usr/lib ; rm -rf libldap-2.3.so.0 )
( cd usr/lib ; ln -sf libldap-2.3.so.0.2.31 libldap-2.3.so.0 )
( cd usr/lib ; rm -rf libgthread-2.0.so.0 )
( cd usr/lib ; ln -sf libgthread-2.0.so.0.2200.5 libgthread-2.0.so.0 )
( cd usr/lib ; rm -rf libjpeg.so.8 )
( cd usr/lib ; ln -sf libjpeg.so.8.0.1 libjpeg.so.8 )
( cd usr/lib ; rm -rf libpcre.so.0 )
( cd usr/lib ; ln -sf libpcre.so.0.0.1 libpcre.so.0 )
( cd usr/lib ; rm -rf liblber-2.4.so.2 )
( cd usr/lib ; ln -sf liblber-2.4.so.2.5.4 liblber-2.4.so.2 )
( cd usr/lib ; rm -rf libgdbm.so.2 )
( cd usr/lib ; ln -sf libgdbm.so.2.0.0 libgdbm.so.2 )
( cd usr/lib ; rm -rf libidn.so.11 )
( cd usr/lib ; ln -sf libidn.so.11.5.34 libidn.so.11 )
( cd usr/lib ; rm -rf libcurl.so.2 )
( cd usr/lib ; ln -sf libcurl.so.2.0.2 libcurl.so.2 )
( cd usr/lib ; rm -rf libfreetype.so.6 )
( cd usr/lib ; ln -sf libfreetype.so.6.4.0 libfreetype.so.6 )
( cd usr/lib ; rm -rf libmenu.so.5 )
( cd usr/lib ; ln -sf libmenu.so.5.7 libmenu.so.5 )
( cd usr/lib ; rm -rf libgmp.so.10 )
( cd usr/lib ; ln -sf libgmp.so.10.0.1 libgmp.so.10 )
( cd usr/lib ; rm -rf libusb-0.1.so.4 )
( cd usr/lib ; ln -sf libusb-0.1.so.4.4.4 libusb-0.1.so.4 )
( cd usr/lib ; rm -rf libtiff.so.3 )
( cd usr/lib ; ln -sf libtiff.so.3.9.2 libtiff.so.3 )
( cd usr/lib ; rm -rf libldap-2.4.so.2 )
( cd usr/lib ; ln -sf libldap-2.4.so.2.5.4 libldap-2.4.so.2 )
( cd lib ; rm -rf libfuse.so.2 )
( cd lib ; ln -sf libfuse.so.2.8.1 libfuse.so.2 )
( cd lib ; rm -rf libbz2.so.1 )
( cd lib ; ln -sf libbz2.so.1.0 libbz2.so.1 )
( cd lib ; rm -rf libgpm.so.1 )
( cd lib ; ln -sf libgpm.so.1.19.0 libgpm.so.1 )
( cd lib ; rm -rf libtermcap.so.2 )
( cd lib ; ln -sf libtermcap.so.2.0.8 libtermcap.so.2 )
( cd lib ; rm -rf libncurses.so.5 )
( cd lib ; ln -sf libncurses.so.5.7 libncurses.so.5 )
( cd lib ; rm -rf libsysfs.so.2 )
( cd lib ; ln -sf libsysfs.so.2.0.1 libsysfs.so.2 )
( cd lib ; rm -rf libpopt.so.0 )
( cd lib ; ln -sf libpopt.so.0.0.0 libpopt.so.0 )
( cd lib ; rm -rf libncursesw.so.5 )
( cd lib ; ln -sf libncursesw.so.5.7 libncursesw.so.5 )
( cd lib ; rm -rf libattr.so.1 )
( cd lib ; ln -sf libattr.so.1.1.0 libattr.so.1 )
( cd lib ; rm -rf libcap.so.2 )
( cd lib ; ln -sf libcap.so.2.19 libcap.so.2 )
( cd lib ; rm -rf libdm.so.0 )
( cd lib ; ln -sf libdm.so.0.0.4 libdm.so.0 )
( cd lib ; rm -rf libbz2.so.1.0 )
( cd lib ; ln -sf libbz2.so.1.0.4 libbz2.so.1.0 )
( cd lib ; rm -rf libacl.so.1 )
( cd lib ; ln -sf libacl.so.1.1.0 libacl.so.1 )
# Package bzip2-1.0.5-i486-1
( cd lib ; rm -rf libbz2.so.1.0 )
( cd lib ; ln -sf libbz2.so.1.0.4 libbz2.so.1.0 )
( cd lib ; rm -rf libbz2.so.1 )
( cd lib ; ln -sf libbz2.so.1.0 libbz2.so.1 )
( cd usr/bin/32 ; rm -rf bzless )
( cd usr/bin/32 ; ln -sf bzmore bzless )
( cd usr/bin/32 ; rm -rf bunzip2 )
( cd usr/bin/32 ; ln -sf ../../bin/bzip2 bunzip2 )
( cd usr/bin/32 ; rm -rf bzcat )
( cd usr/bin/32 ; ln -sf ../../bin/bzip2 bzcat )
( cd usr/bin/32 ; rm -rf bzip2 )
( cd usr/bin/32 ; ln -sf ../../bin/bzip2 bzip2 )
( cd usr/lib ; rm -rf libbz2.so )
( cd usr/lib ; ln -sf ../../lib/libbz2.so.1 libbz2.so )
# Package cups-1.4.3-i486-3
( cd usr/lib ; rm -rf libcupsppdc.so )
( cd usr/lib ; ln -sf libcupsppdc.so.1 libcupsppdc.so )
( cd usr/lib ; rm -rf libcupscgi.so )
( cd usr/lib ; ln -sf libcupscgi.so.1 libcupscgi.so )
( cd usr/lib ; rm -rf libcupsmime.so )
( cd usr/lib ; ln -sf libcupsmime.so.1 libcupsmime.so )
( cd usr/lib/cups/filter ; rm -rf rastertodymo )
( cd usr/lib/cups/filter ; ln -sf rastertolabel rastertodymo )
( cd usr/lib/cups/backend ; rm -rf smb )
( cd usr/lib/cups/backend ; ln -sf /usr/bin/32/smbspool smb )
( cd usr/lib/cups/backend ; rm -rf http )
( cd usr/lib/cups/backend ; ln -sf ipp http )
( cd usr/lib ; rm -rf libcups.so )
( cd usr/lib ; ln -sf libcups.so.2 libcups.so )
( cd usr/lib ; rm -rf libcupsimage.so )
( cd usr/lib ; ln -sf libcupsimage.so.2 libcupsimage.so )
( cd usr/lib ; rm -rf libcupsdriver.so )
( cd usr/lib ; ln -sf libcupsdriver.so.1 libcupsdriver.so )
( cd usr/bin/32 ; rm -rf cancel )
( cd usr/bin/32 ; ln -sf cancel-cups cancel )
( cd usr/bin/32 ; rm -rf lpr )
( cd usr/bin/32 ; ln -sf lpr-cups lpr )
( cd usr/bin/32 ; rm -rf lprm )
( cd usr/bin/32 ; ln -sf lprm-cups lprm )
( cd usr/bin/32 ; rm -rf lpq )
( cd usr/bin/32 ; ln -sf lpq-cups lpq )
( cd usr/bin/32 ; rm -rf lp )
( cd usr/bin/32 ; ln -sf lp-cups lp )
( cd usr/bin/32 ; rm -rf lpstat )
( cd usr/bin/32 ; ln -sf lpstat-cups lpstat )
# Package cxxlibs-6.0.13-i486-2
( cd usr/lib ; rm -rf libstdc++.so.4 )
( cd usr/lib ; ln -sf libstdc++.so.4.0.0 libstdc++.so.4 )
( cd usr/lib ; rm -rf libstdc++.so.5 )
( cd usr/lib ; ln -sf libstdc++.so.5.0.7 libstdc++.so.5 )
( cd usr/lib ; rm -rf libstdc++-libc6.2-2.so.3 )
( cd usr/lib ; ln -sf libstdc++-3-libc6.2-2-2.10.0.so libstdc++-libc6.2-2.so.3 )
( cd usr/lib ; rm -rf libstdc++-libc6.1-2.so.3 )
( cd usr/lib ; ln -sf libstdc++-3-libc6.1-2-2.10.0.so libstdc++-libc6.1-2.so.3 )
# Package dbus-1.2.24-i486-2
( cd usr/lib ; rm -rf libdbus-1.so )
( cd usr/lib ; ln -sf libdbus-1.so.3.4.0 libdbus-1.so )
( cd usr/lib ; rm -rf libdbus-1.so.3 )
( cd usr/lib ; ln -sf libdbus-1.so.3.4.0 libdbus-1.so.3 )
# Package e2fsprogs-1.41.11-i486-1
( cd lib ; rm -rf libss.so.2 )
( cd lib ; ln -sf libss.so.2.0 libss.so.2 )
( cd lib ; rm -rf libcom_err.so.2 )
( cd lib ; ln -sf libcom_err.so.2.1 libcom_err.so.2 )
( cd lib ; rm -rf libext2fs.so.2 )
( cd lib ; ln -sf libext2fs.so.2.4 libext2fs.so.2 )
( cd lib ; rm -rf libe2p.so.2 )
( cd lib ; ln -sf libe2p.so.2.3 libe2p.so.2 )
( cd usr/lib ; rm -rf libss.so )
( cd usr/lib ; ln -sf /lib/libss.so.2 libss.so )
( cd usr/lib ; rm -rf libe2p.so )
( cd usr/lib ; ln -sf /lib/libe2p.so.2 libe2p.so )
( cd usr/lib ; rm -rf libext2fs.so )
( cd usr/lib ; ln -sf /lib/libext2fs.so.2 libext2fs.so )
( cd usr/lib ; rm -rf libcom_err.so )
( cd usr/lib ; ln -sf /lib/libcom_err.so.2 libcom_err.so )
# Package util-linux-ng-2.17.2-i486-1
( cd lib ; rm -rf libblkid.so.1 )
( cd lib ; ln -sf libblkid.so.1.1.0 libblkid.so.1 )
( cd lib ; rm -rf libuuid.so.1 )
( cd lib ; ln -sf libuuid.so.1.3.0 libuuid.so.1 )
( cd usr/bin/32 ; rm -rf getopt )
( cd usr/bin/32 ; ln -sf ../../bin/getopt getopt )
( cd usr/bin/32 ; rm -rf readprofile )
( cd usr/bin/32 ; ln -sf ../sbin/readprofile readprofile )
( cd usr/bin/32 ; rm -rf linux64 )
( cd usr/bin/32 ; ln -sf setarch linux64 )
( cd usr/bin/32 ; rm -rf setterm )
( cd usr/bin/32 ; ln -sf ../../bin/setterm setterm )
( cd usr/bin/32 ; rm -rf i386 )
( cd usr/bin/32 ; ln -sf setarch i386 )
( cd usr/bin/32 ; rm -rf more )
( cd usr/bin/32 ; ln -sf ../../bin/more more )
( cd usr/bin/32 ; rm -rf raw )
( cd usr/bin/32 ; ln -sf ../../sbin/raw raw )
( cd usr/bin/32 ; rm -rf linux32 )
( cd usr/bin/32 ; ln -sf setarch linux32 )
( cd usr/bin/32 ; rm -rf tunelp )
( cd usr/bin/32 ; ln -sf ../sbin/tunelp tunelp )
( cd usr/lib ; rm -rf libuuid.so )
( cd usr/lib ; ln -sf /lib/libuuid.so.1 libuuid.so )
( cd usr/lib ; rm -rf libblkid.so )
( cd usr/lib ; ln -sf /lib/libblkid.so.1 libblkid.so )
# Package mpg123-1.12.1-i486-1
( cd usr/bin/32 ; rm -rf mpg321 )
( cd usr/bin/32 ; ln -sf mpg123 mpg321 )
( cd usr/lib ; rm -rf libmpg123.so )
( cd usr/lib ; ln -sf libmpg123.so.0.25.0 libmpg123.so )
( cd usr/lib ; rm -rf libmpg123.so.0 )
( cd usr/lib ; ln -sf libmpg123.so.0.25.0 libmpg123.so.0 )
# Package mysql-5.1.46-i486-2
( cd usr/lib ; rm -rf libmysqlclient_r.so.16 )
( cd usr/lib ; ln -sf mysql/libmysqlclient_r.so.16 libmysqlclient_r.so.16 )
( cd usr/lib/mysql ; rm -rf libmysqlclient_r.so.16 )
( cd usr/lib/mysql ; ln -sf libmysqlclient_r.so.16.0.0 libmysqlclient_r.so.16 )
( cd usr/lib/mysql ; rm -rf libmysqlclient_r.so )
( cd usr/lib/mysql ; ln -sf libmysqlclient_r.so.16.0.0 libmysqlclient_r.so )
( cd usr/lib/mysql ; rm -rf libmysqlclient.so )
( cd usr/lib/mysql ; ln -sf libmysqlclient.so.16.0.0 libmysqlclient.so )
( cd usr/lib/mysql ; rm -rf libmysqlclient.so.16 )
( cd usr/lib/mysql ; ln -sf libmysqlclient.so.16.0.0 libmysqlclient.so.16 )
( cd usr/lib/mysql/plugin ; rm -rf ha_example.so.0 )
( cd usr/lib/mysql/plugin ; ln -sf ha_example.so.0.0.0 ha_example.so.0 )
( cd usr/lib/mysql/plugin ; rm -rf ha_innodb_plugin.so.0 )
( cd usr/lib/mysql/plugin ; ln -sf ha_innodb_plugin.so.0.0.0 ha_innodb_plugin.so.0 )
( cd usr/lib/mysql/plugin ; rm -rf mypluglib.so )
( cd usr/lib/mysql/plugin ; ln -sf mypluglib.so.0.0.0 mypluglib.so )
( cd usr/lib/mysql/plugin ; rm -rf mypluglib.so.0 )
( cd usr/lib/mysql/plugin ; ln -sf mypluglib.so.0.0.0 mypluglib.so.0 )
( cd usr/lib/mysql/plugin ; rm -rf ha_federated.so )
( cd usr/lib/mysql/plugin ; ln -sf ha_federated.so.0.0.0 ha_federated.so )
( cd usr/lib/mysql/plugin ; rm -rf ha_archive.so.0 )
( cd usr/lib/mysql/plugin ; ln -sf ha_archive.so.0.0.0 ha_archive.so.0 )
( cd usr/lib/mysql/plugin ; rm -rf ha_blackhole.so.0 )
( cd usr/lib/mysql/plugin ; ln -sf ha_blackhole.so.0.0.0 ha_blackhole.so.0 )
( cd usr/lib/mysql/plugin ; rm -rf ha_blackhole.so )
( cd usr/lib/mysql/plugin ; ln -sf ha_blackhole.so.0.0.0 ha_blackhole.so )
( cd usr/lib/mysql/plugin ; rm -rf ha_archive.so )
( cd usr/lib/mysql/plugin ; ln -sf ha_archive.so.0.0.0 ha_archive.so )
( cd usr/lib/mysql/plugin ; rm -rf libdaemon_example.so )
( cd usr/lib/mysql/plugin ; ln -sf libdaemon_example.so.0.0.0 libdaemon_example.so )
( cd usr/lib/mysql/plugin ; rm -rf ha_federated.so.0 )
( cd usr/lib/mysql/plugin ; ln -sf ha_federated.so.0.0.0 ha_federated.so.0 )
( cd usr/lib/mysql/plugin ; rm -rf libdaemon_example.so.0 )
( cd usr/lib/mysql/plugin ; ln -sf libdaemon_example.so.0.0.0 libdaemon_example.so.0 )
( cd usr/lib/mysql/plugin ; rm -rf ha_example.so )
( cd usr/lib/mysql/plugin ; ln -sf ha_example.so.0.0.0 ha_example.so )
( cd usr/lib/mysql/plugin ; rm -rf ha_innodb_plugin.so )
( cd usr/lib/mysql/plugin ; ln -sf ha_innodb_plugin.so.0.0.0 ha_innodb_plugin.so )
( cd usr/lib ; rm -rf libmysqlclient_r.so )
( cd usr/lib ; ln -sf mysql/libmysqlclient_r.so libmysqlclient_r.so )
( cd usr/lib ; rm -rf libmysqlclient.so )
( cd usr/lib ; ln -sf mysql/libmysqlclient.so libmysqlclient.so )
( cd usr/lib ; rm -rf libmysqlclient.so.16 )
( cd usr/lib ; ln -sf mysql/libmysqlclient.so.16 libmysqlclient.so.16 )
# Package sqlite-3.6.23.1-i486-1
( cd usr/lib ; rm -rf libsqlite3.so )
( cd usr/lib ; ln -sf libsqlite3.so.0.8.6 libsqlite3.so )
( cd usr/lib ; rm -rf libsqlite3.so.0 )
( cd usr/lib ; ln -sf libsqlite3.so.0.8.6 libsqlite3.so.0 )
# Package libtool-2.2.6b-i486-2
( cd usr/lib ; rm -rf libltdl.so.7 )
( cd usr/lib ; ln -sf libltdl.so.7.2.1 libltdl.so.7 )
( cd usr/lib ; rm -rf libltdl.so )
( cd usr/lib ; ln -sf libltdl.so.7.2.1 libltdl.so )
# Package alsa-lib-1.0.23-i486-1
( cd usr/lib ; rm -rf libasound.so.2 )
( cd usr/lib ; ln -sf libasound.so.2.0.0 libasound.so.2 )
( cd usr/lib ; rm -rf libasound.so )
( cd usr/lib ; ln -sf libasound.so.2.0.0 libasound.so )
# Package alsa-oss-1.0.17-i486-1
( cd usr/lib ; rm -rf libalsatoss.so.0 )
( cd usr/lib ; ln -sf libalsatoss.so.0.0.0 libalsatoss.so.0 )
( cd usr/lib ; rm -rf libaoss.so.0 )
( cd usr/lib ; ln -sf libaoss.so.0.0.0 libaoss.so.0 )
( cd usr/lib ; rm -rf libalsatoss.so )
( cd usr/lib ; ln -sf libalsatoss.so.0.0.0 libalsatoss.so )
( cd usr/lib ; rm -rf libaoss.so )
( cd usr/lib ; ln -sf libaoss.so.0.0.0 libaoss.so )
# Package atk-1.30.0-i486-1
( cd usr/lib ; rm -rf libatk-1.0.so.0 )
( cd usr/lib ; ln -sf libatk-1.0.so.0.3009.1 libatk-1.0.so.0 )
( cd usr/lib ; rm -rf libatk-1.0.so )
( cd usr/lib ; ln -sf libatk-1.0.so.0.3009.1 libatk-1.0.so )
# Package audiofile-0.2.6-i486-2
( cd usr/lib ; rm -rf libaudiofile.so )
( cd usr/lib ; ln -sf libaudiofile.so.0.0.2 libaudiofile.so )
( cd usr/lib ; rm -rf libaudiofile.so.0 )
( cd usr/lib ; ln -sf libaudiofile.so.0.0.2 libaudiofile.so.0 )
# Package cairo-1.8.8-i486-3
( cd usr/lib ; rm -rf libcairo.so.2 )
( cd usr/lib ; ln -sf libcairo.so.2.10800.8 libcairo.so.2 )
( cd usr/lib ; rm -rf libcairo.so )
( cd usr/lib ; ln -sf libcairo.so.2.10800.8 libcairo.so )
# Package dbus-glib-0.86-i486-1
( cd usr/lib ; rm -rf libdbus-glib-1.so.2 )
( cd usr/lib ; ln -sf libdbus-glib-1.so.2.1.0 libdbus-glib-1.so.2 )
( cd usr/lib ; rm -rf libdbus-glib-1.so )
( cd usr/lib ; ln -sf libdbus-glib-1.so.2.1.0 libdbus-glib-1.so )
# Package esound-0.2.41-i486-1
( cd usr/lib ; rm -rf libesddsp.so )
( cd usr/lib ; ln -sf libesddsp.so.0.2.39 libesddsp.so )
( cd usr/lib ; rm -rf libesd.so )
( cd usr/lib ; ln -sf libesd.so.0.2.39 libesd.so )
( cd usr/lib ; rm -rf libesddsp.so.0 )
( cd usr/lib ; ln -sf libesddsp.so.0.2.39 libesddsp.so.0 )
( cd usr/lib ; rm -rf libesd.so.0 )
( cd usr/lib ; ln -sf libesd.so.0.2.39 libesd.so.0 )
# Package expat-2.0.1-i486-1
( cd usr/lib ; rm -rf libexpat.so.1 )
( cd usr/lib ; ln -sf libexpat.so.1.5.2 libexpat.so.1 )
( cd usr/lib ; rm -rf libexpat.so )
( cd usr/lib ; ln -sf libexpat.so.1.5.2 libexpat.so )
# Package freetype-2.3.12-i486-1
( cd usr/lib ; rm -rf libfreetype.so.6 )
( cd usr/lib ; ln -sf libfreetype.so.6.4.0 libfreetype.so.6 )
( cd usr/lib ; rm -rf libfreetype.so )
( cd usr/lib ; ln -sf libfreetype.so.6.4.0 libfreetype.so )
# Package gamin-0.1.10-i486-2
( cd usr/lib ; rm -rf libgamin-1.so.0 )
( cd usr/lib ; ln -sf libgamin-1.so.0.1.10 libgamin-1.so.0 )
( cd usr/lib ; rm -rf libfam.so )
( cd usr/lib ; ln -sf libfam.so.0.0.0 libfam.so )
( cd usr/lib ; rm -rf libgamin-1.so )
( cd usr/lib ; ln -sf libgamin-1.so.0.1.10 libgamin-1.so )
( cd usr/lib ; rm -rf libfam.so.0 )
( cd usr/lib ; ln -sf libfam.so.0.0.0 libfam.so.0 )
# Package glib2-2.22.5-i486-1
( cd usr/lib ; rm -rf libgthread-2.0.so.0 )
( cd usr/lib ; ln -sf libgthread-2.0.so.0.2200.5 libgthread-2.0.so.0 )
( cd usr/lib ; rm -rf libgthread-2.0.so )
( cd usr/lib ; ln -sf libgthread-2.0.so.0.2200.5 libgthread-2.0.so )
( cd usr/lib ; rm -rf libgmodule-2.0.so.0 )
( cd usr/lib ; ln -sf libgmodule-2.0.so.0.2200.5 libgmodule-2.0.so.0 )
( cd usr/lib ; rm -rf libglib-2.0.so )
( cd usr/lib ; ln -sf libglib-2.0.so.0.2200.5 libglib-2.0.so )
( cd usr/lib ; rm -rf libgio-2.0.so.0 )
( cd usr/lib ; ln -sf libgio-2.0.so.0.2200.5 libgio-2.0.so.0 )
( cd usr/lib ; rm -rf libgobject-2.0.so )
( cd usr/lib ; ln -sf libgobject-2.0.so.0.2200.5 libgobject-2.0.so )
( cd usr/lib ; rm -rf libgmodule-2.0.so )
( cd usr/lib ; ln -sf libgmodule-2.0.so.0.2200.5 libgmodule-2.0.so )
( cd usr/lib ; rm -rf libglib-2.0.so.0 )
( cd usr/lib ; ln -sf libglib-2.0.so.0.2200.5 libglib-2.0.so.0 )
( cd usr/lib ; rm -rf libgobject-2.0.so.0 )
( cd usr/lib ; ln -sf libgobject-2.0.so.0.2200.5 libgobject-2.0.so.0 )
( cd usr/lib ; rm -rf libgio-2.0.so )
( cd usr/lib ; ln -sf libgio-2.0.so.0.2200.5 libgio-2.0.so )
# Package libart_lgpl-2.3.20-i486-1
( cd usr/lib ; rm -rf libart_lgpl_2.so.2 )
( cd usr/lib ; ln -sf libart_lgpl_2.so.2.3.20 libart_lgpl_2.so.2 )
( cd usr/lib ; rm -rf libart_lgpl_2.so )
( cd usr/lib ; ln -sf libart_lgpl_2.so.2.3.20 libart_lgpl_2.so )
# Package libexif-0.6.19-i486-1
( cd usr/lib ; rm -rf libexif.so.12 )
( cd usr/lib ; ln -sf libexif.so.12.3.1 libexif.so.12 )
( cd usr/lib ; rm -rf libexif.so )
( cd usr/lib ; ln -sf libexif.so.12.3.1 libexif.so )
# Package libidn-1.5-i486-1
( cd usr/lib ; rm -rf libidn.so )
( cd usr/lib ; ln -sf libidn.so.11.5.34 libidn.so )
( cd usr/lib ; rm -rf libidn.so.11 )
( cd usr/lib ; ln -sf libidn.so.11.5.34 libidn.so.11 )
# Package libjpeg-v8a-i486-1
( cd usr/lib ; rm -rf libjpeg.so )
( cd usr/lib ; ln -sf libjpeg.so.8.0.1 libjpeg.so )
( cd usr/lib ; rm -rf libjpeg.so.8 )
( cd usr/lib ; ln -sf libjpeg.so.8.0.1 libjpeg.so.8 )
# Package libmng-1.0.10-i486-2
( cd usr/lib ; rm -rf libmng.so.1 )
( cd usr/lib ; ln -sf libmng.so.1.0.0 libmng.so.1 )
( cd usr/lib ; rm -rf libmng.so )
( cd usr/lib ; ln -sf libmng.so.1.0.0 libmng.so )
# Package libpng-1.4.2-i486-1
( cd usr/bin/32 ; rm -rf libpng-config )
( cd usr/bin/32 ; ln -sf libpng14-config libpng-config )
( cd usr/lib ; rm -rf libpng12.so )
( cd usr/lib ; ln -sf libpng12.so.0.43.0 libpng12.so )
( cd usr/lib ; rm -rf libpng12.so.0 )
( cd usr/lib ; ln -sf libpng12.so.0.43.0 libpng12.so.0 )
( cd usr/lib ; rm -rf libpng14.so )
( cd usr/lib ; ln -sf libpng14.so.14.2.0 libpng14.so )
( cd usr/lib ; rm -rf libpng.la )
( cd usr/lib ; ln -sf libpng14.la libpng.la )
( cd usr/lib ; rm -rf libpng.so.14 )
( cd usr/lib ; ln -sf libpng14.so.14 libpng.so.14 )
( cd usr/lib ; rm -rf libpng.so.3 )
( cd usr/lib ; ln -sf libpng.so.3.43.0 libpng.so.3 )
( cd usr/lib ; rm -rf libpng.so )
( cd usr/lib ; ln -sf libpng14.so libpng.so )
( cd usr/lib ; rm -rf libpng.a )
( cd usr/lib ; ln -sf libpng14.a libpng.a )
( cd usr/lib/pkgconfig ; rm -rf libpng.pc )
( cd usr/lib/pkgconfig ; ln -sf libpng14.pc libpng.pc )
( cd usr/lib ; rm -rf libpng14.so.14 )
( cd usr/lib ; ln -sf libpng14.so.14.2.0 libpng14.so.14 )
# Package libtermcap-1.2.3-i486-7
( cd lib ; rm -rf libtermcap.so.2 )
( cd lib ; ln -sf libtermcap.so.2.0.8 libtermcap.so.2 )
( cd usr/lib ; rm -rf libtermcap.so )
( cd usr/lib ; ln -sf /lib/libtermcap.so.2.0.8 libtermcap.so )
# Package libtiff-3.9.2-i486-1
( cd usr/lib ; rm -rf libtiffxx.so )
( cd usr/lib ; ln -sf libtiffxx.so.3.9.2 libtiffxx.so )
( cd usr/lib ; rm -rf libtiffxx.so.3 )
( cd usr/lib ; ln -sf libtiffxx.so.3.9.2 libtiffxx.so.3 )
( cd usr/lib ; rm -rf libtiff.so )
( cd usr/lib ; ln -sf libtiff.so.3.9.2 libtiff.so )
( cd usr/lib ; rm -rf libtiff.so.3 )
( cd usr/lib ; ln -sf libtiff.so.3.9.2 libtiff.so.3 )
# Package libxml2-2.7.6-i486-1
rm -f /usr/lib/python26/site-packages/libxml2.pyc
rm -f /usr/lib/python26/site-packages/drv_libxml2.pyc
( cd usr/lib ; rm -rf libxml2.so.2 )
( cd usr/lib ; ln -sf libxml2.so.2.7.6 libxml2.so.2 )
( cd usr/lib ; rm -rf libxml2.so )
( cd usr/lib ; ln -sf libxml2.so.2.7.6 libxml2.so )
# Package jasper-1.900.1-i486-3
( cd usr/lib ; rm -rf libjasper.so )
( cd usr/lib ; ln -sf libjasper.so.1.0.0 libjasper.so )
( cd usr/lib ; rm -rf libjasper.so.1 )
( cd usr/lib ; ln -sf libjasper.so.1.0.0 libjasper.so.1 )
# Package lcms-1.19-i486-1
( cd usr/lib ; rm -rf liblcms.so.1 )
( cd usr/lib ; ln -sf liblcms.so.1.0.19 liblcms.so.1 )
( cd usr/lib ; rm -rf liblcms.so )
( cd usr/lib ; ln -sf liblcms.so.1.0.19 liblcms.so )
# Package libxslt-1.1.26-i486-1
( cd usr/lib ; rm -rf libxslt.so )
( cd usr/lib ; ln -sf libxslt.so.1.1.26 libxslt.so )
( cd usr/lib ; rm -rf libexslt.so )
( cd usr/lib ; ln -sf libexslt.so.0.8.15 libexslt.so )
( cd usr/lib ; rm -rf libexslt.so.0 )
( cd usr/lib ; ln -sf libexslt.so.0.8.15 libexslt.so.0 )
( cd usr/lib ; rm -rf libxslt.so.1 )
( cd usr/lib ; ln -sf libxslt.so.1.1.26 libxslt.so.1 )
# Package ncurses-5.7-i486-1
( cd usr/lib ; rm -rf libcurses.so )
( cd usr/lib ; ln -sf libncurses.so libcurses.so )
( cd usr/lib ; rm -rf libpanelw.so )
( cd usr/lib ; ln -sf libpanelw.so.5 libpanelw.so )
( cd usr/lib ; rm -rf libpanelw.so.5 )
( cd usr/lib ; ln -sf libpanelw.so.5.7 libpanelw.so.5 )
( cd usr/lib ; rm -rf libncursesw.so )
( cd usr/lib ; ln -sf /lib/libncursesw.so.5 libncursesw.so )
( cd usr/lib ; rm -rf libpanel.so )
( cd usr/lib ; ln -sf libpanel.so.5 libpanel.so )
( cd usr/lib ; rm -rf libpanel.so.5 )
( cd usr/lib ; ln -sf libpanel.so.5.7 libpanel.so.5 )
( cd usr/lib ; rm -rf libform.so.5 )
( cd usr/lib ; ln -sf libform.so.5.7 libform.so.5 )
( cd usr/lib ; rm -rf libcursesw.so )
( cd usr/lib ; ln -sf libncursesw.so libcursesw.so )
( cd usr/lib ; rm -rf libmenuw.so.5 )
( cd usr/lib ; ln -sf libmenuw.so.5.7 libmenuw.so.5 )
( cd usr/lib ; rm -rf libmenuw.so )
( cd usr/lib ; ln -sf libmenuw.so.5 libmenuw.so )
( cd usr/lib ; rm -rf libncurses.so )
( cd usr/lib ; ln -sf /lib/libncurses.so.5 libncurses.so )
( cd usr/lib ; rm -rf libmenu.so )
( cd usr/lib ; ln -sf libmenu.so.5 libmenu.so )
( cd usr/lib ; rm -rf libform.so )
( cd usr/lib ; ln -sf libform.so.5 libform.so )
( cd usr/lib ; rm -rf libcurses.a )
( cd usr/lib ; ln -sf libncurses.a libcurses.a )
( cd usr/lib ; rm -rf libformw.so )
( cd usr/lib ; ln -sf libformw.so.5 libformw.so )
( cd usr/lib ; rm -rf libmenu.so.5 )
( cd usr/lib ; ln -sf libmenu.so.5.7 libmenu.so.5 )
( cd usr/lib ; rm -rf terminfo )
( cd usr/lib ; ln -sf ../share/terminfo terminfo )
( cd usr/lib ; rm -rf libformw.so.5 )
( cd usr/lib ; ln -sf libformw.so.5.7 libformw.so.5 )
( cd usr/bin/32 ; rm -rf captoinfo )
( cd usr/bin/32 ; ln -sf tic captoinfo )
( cd usr/bin/32 ; rm -rf infotocap )
( cd usr/bin/32 ; ln -sf tic infotocap )
( cd usr/bin/32 ; rm -rf reset )
( cd usr/bin/32 ; ln -sf tset reset )
( cd lib ; rm -rf libncursesw.so.5 )
( cd lib ; ln -sf libncursesw.so.5.7 libncursesw.so.5 )
( cd lib ; rm -rf libncurses.so.5 )
( cd lib ; ln -sf libncurses.so.5.7 libncurses.so.5 )
# Package svgalib-1.9.25-i486-2
( cd usr/lib ; rm -rf lib3dkit.so )
( cd usr/lib ; ln -sf lib3dkit.so.1.9.25 lib3dkit.so )
( cd usr/lib ; rm -rf libvgagl.so )
( cd usr/lib ; ln -sf libvgagl.so.1.9.25 libvgagl.so )
( cd usr/lib ; rm -rf libvga.so )
( cd usr/lib ; ln -sf libvga.so.1.9.25 libvga.so )
# Package v4l-utils-0.8.0-i486-1
( cd usr/lib ; rm -rf libv4l1.so )
( cd usr/lib ; ln -sf libv4l1.so.0 libv4l1.so )
( cd usr/lib ; rm -rf libv4lconvert.so )
( cd usr/lib ; ln -sf libv4lconvert.so.0 libv4lconvert.so )
( cd usr/lib ; rm -rf libv4l2.so )
( cd usr/lib ; ln -sf libv4l2.so.0 libv4l2.so )
# Package popt-1.7-i486-3
( cd lib ; rm -rf libpopt.so.0 )
( cd lib ; ln -sf libpopt.so.0.0.0 libpopt.so.0 )
( cd usr/lib ; rm -rf libpopt.so.0 )
( cd usr/lib ; ln -sf libpopt.so.0.0.0 libpopt.so.0 )
( cd usr/lib ; rm -rf libpopt.so )
( cd usr/lib ; ln -sf libpopt.so.0.0.0 libpopt.so )
( cd usr/lib ; rm -rf libpopt.so.0.0.0 )
( cd usr/lib ; ln -sf ../../lib/libpopt.so.0.0.0 libpopt.so.0.0.0 )
# Package qt-4.6.2_2d3d3e5-i486-1
( cd usr/lib ; rm -rf libQtXml.so.4 )
( cd usr/lib ; ln -sf qt/lib/libQtXml.so.4 libQtXml.so.4 )
( cd usr/lib ; rm -rf libQtTest.so )
( cd usr/lib ; ln -sf qt/lib/libQtTest.so libQtTest.so )
( cd usr/lib ; rm -rf libQtXml.so.4.6.2 )
( cd usr/lib ; ln -sf qt/lib/libQtXml.so.4.6.2 libQtXml.so.4.6.2 )
( cd usr/lib ; rm -rf libQtTest.so.4.6 )
( cd usr/lib ; ln -sf qt/lib/libQtTest.so.4.6 libQtTest.so.4.6 )
( cd usr/lib ; rm -rf libQtSvg.so.4 )
( cd usr/lib ; ln -sf qt/lib/libQtSvg.so.4 libQtSvg.so.4 )
( cd usr/lib ; rm -rf libQtCLucene.so.4.6.2 )
( cd usr/lib ; ln -sf qt/lib/libQtCLucene.so.4.6.2 libQtCLucene.so.4.6.2 )
( cd usr/lib ; rm -rf libQtWebKit.so.4 )
( cd usr/lib ; ln -sf qt/lib/libQtWebKit.so.4 libQtWebKit.so.4 )
( cd usr/lib ; rm -rf libQtTest.so.4 )
( cd usr/lib ; ln -sf qt/lib/libQtTest.so.4 libQtTest.so.4 )
( cd usr/lib ; rm -rf libQtOpenGL.so.4.6.2 )
( cd usr/lib ; ln -sf qt/lib/libQtOpenGL.so.4.6.2 libQtOpenGL.so.4.6.2 )
( cd usr/lib ; rm -rf libQtScript.so.4.6.2 )
( cd usr/lib ; ln -sf qt/lib/libQtScript.so.4.6.2 libQtScript.so.4.6.2 )
( cd usr/lib ; rm -rf libQtCore.so.4 )
( cd usr/lib ; ln -sf qt/lib/libQtCore.so.4 libQtCore.so.4 )
( cd usr/lib ; rm -rf libQtMultimedia.so.4 )
( cd usr/lib ; ln -sf qt/lib/libQtMultimedia.so.4 libQtMultimedia.so.4 )
( cd usr/lib ; rm -rf libQtWebKit.so.4.6 )
( cd usr/lib ; ln -sf qt/lib/libQtWebKit.so.4.6 libQtWebKit.so.4.6 )
( cd usr/lib ; rm -rf libQtWebKit.so.4.6.2 )
( cd usr/lib ; ln -sf qt/lib/libQtWebKit.so.4.6.2 libQtWebKit.so.4.6.2 )
( cd usr/lib ; rm -rf libQtWebKit.so )
( cd usr/lib ; ln -sf qt/lib/libQtWebKit.so libQtWebKit.so )
( cd usr/lib ; rm -rf libQtCLucene.so.4.6 )
( cd usr/lib ; ln -sf qt/lib/libQtCLucene.so.4.6 libQtCLucene.so.4.6 )
( cd usr/lib ; rm -rf libQtScriptTools.so.4.6 )
( cd usr/lib ; ln -sf qt/lib/libQtScriptTools.so.4.6 libQtScriptTools.so.4.6 )
( cd usr/lib ; rm -rf libQtGui.so.4.6 )
( cd usr/lib ; ln -sf qt/lib/libQtGui.so.4.6 libQtGui.so.4.6 )
( cd usr/lib ; rm -rf libQtSvg.so )
( cd usr/lib ; ln -sf qt/lib/libQtSvg.so libQtSvg.so )
( cd usr/lib ; rm -rf libQtNetwork.so.4.6 )
( cd usr/lib ; ln -sf qt/lib/libQtNetwork.so.4.6 libQtNetwork.so.4.6 )
( cd usr/lib ; rm -rf libQtAssistantClient.so.4.6 )
( cd usr/lib ; ln -sf qt/lib/libQtAssistantClient.so.4.6 libQtAssistantClient.so.4.6 )
( cd usr/lib ; rm -rf libQtAssistantClient.so )
( cd usr/lib ; ln -sf qt/lib/libQtAssistantClient.so libQtAssistantClient.so )
( cd usr/lib ; rm -rf libQt3Support.so )
( cd usr/lib ; ln -sf qt/lib/libQt3Support.so libQt3Support.so )
( cd usr/lib ; rm -rf libQtDesignerComponents.so.4.6 )
( cd usr/lib ; ln -sf qt/lib/libQtDesignerComponents.so.4.6 libQtDesignerComponents.so.4.6 )
( cd usr/lib ; rm -rf libQtSql.so )
( cd usr/lib ; ln -sf qt/lib/libQtSql.so libQtSql.so )
( cd usr/lib ; rm -rf libQtMultimedia.so )
( cd usr/lib ; ln -sf qt/lib/libQtMultimedia.so libQtMultimedia.so )
( cd usr/lib ; rm -rf libQtDesignerComponents.so )
( cd usr/lib ; ln -sf qt/lib/libQtDesignerComponents.so libQtDesignerComponents.so )
( cd usr/lib ; rm -rf qt-4.6.2_2d3d3e5 )
( cd usr/lib ; ln -sf qt qt-4.6.2_2d3d3e5 )
( cd usr/lib ; rm -rf libQtScriptTools.so.4 )
( cd usr/lib ; ln -sf qt/lib/libQtScriptTools.so.4 libQtScriptTools.so.4 )
( cd usr/lib ; rm -rf libQtXmlPatterns.so.4.6.2 )
( cd usr/lib ; ln -sf qt/lib/libQtXmlPatterns.so.4.6.2 libQtXmlPatterns.so.4.6.2 )
( cd usr/lib ; rm -rf libQtDBus.so.4.6 )
( cd usr/lib ; ln -sf qt/lib/libQtDBus.so.4.6 libQtDBus.so.4.6 )
( cd usr/lib ; rm -rf libQtOpenGL.so.4 )
( cd usr/lib ; ln -sf qt/lib/libQtOpenGL.so.4 libQtOpenGL.so.4 )
( cd usr/lib ; rm -rf libQtXml.so )
( cd usr/lib ; ln -sf qt/lib/libQtXml.so libQtXml.so )
( cd usr/lib ; rm -rf libQtCore.so )
( cd usr/lib ; ln -sf qt/lib/libQtCore.so libQtCore.so )
( cd usr/lib ; rm -rf libQtHelp.so.4 )
( cd usr/lib ; ln -sf qt/lib/libQtHelp.so.4 libQtHelp.so.4 )
( cd usr/lib ; rm -rf libQtAssistantClient.so.4 )
( cd usr/lib ; ln -sf qt/lib/libQtAssistantClient.so.4 libQtAssistantClient.so.4 )
( cd usr/lib ; rm -rf libQt3Support.so.4.6.2 )
( cd usr/lib ; ln -sf qt/lib/libQt3Support.so.4.6.2 libQt3Support.so.4.6.2 )
( cd usr/lib ; rm -rf libQtCore.so.4.6 )
( cd usr/lib ; ln -sf qt/lib/libQtCore.so.4.6 libQtCore.so.4.6 )
( cd usr/lib ; rm -rf libQtXmlPatterns.so.4 )
( cd usr/lib ; ln -sf qt/lib/libQtXmlPatterns.so.4 libQtXmlPatterns.so.4 )
( cd usr/lib ; rm -rf libQtOpenGL.so.4.6 )
( cd usr/lib ; ln -sf qt/lib/libQtOpenGL.so.4.6 libQtOpenGL.so.4.6 )
( cd usr/lib ; rm -rf libQtGui.so.4 )
( cd usr/lib ; ln -sf qt/lib/libQtGui.so.4 libQtGui.so.4 )
( cd usr/lib ; rm -rf libQtMultimedia.so.4.6 )
( cd usr/lib ; ln -sf qt/lib/libQtMultimedia.so.4.6 libQtMultimedia.so.4.6 )
( cd usr/lib ; rm -rf libQtScriptTools.so )
( cd usr/lib ; ln -sf qt/lib/libQtScriptTools.so libQtScriptTools.so )
( cd usr/lib/qt/lib ; rm -rf libQtXml.so.4 )
( cd usr/lib/qt/lib ; ln -sf libQtXml.so.4.6.2 libQtXml.so.4 )
( cd usr/lib/qt/lib ; rm -rf libQtTest.so )
( cd usr/lib/qt/lib ; ln -sf libQtTest.so.4.6.2 libQtTest.so )
( cd usr/lib/qt/lib ; rm -rf libQtTest.so.4.6 )
( cd usr/lib/qt/lib ; ln -sf libQtTest.so.4.6.2 libQtTest.so.4.6 )
( cd usr/lib/qt/lib ; rm -rf libQtSvg.so.4 )
( cd usr/lib/qt/lib ; ln -sf libQtSvg.so.4.6.2 libQtSvg.so.4 )
( cd usr/lib/qt/lib ; rm -rf libQtWebKit.so.4 )
( cd usr/lib/qt/lib ; ln -sf libQtWebKit.so.4.6.2 libQtWebKit.so.4 )
( cd usr/lib/qt/lib ; rm -rf libQtTest.so.4 )
( cd usr/lib/qt/lib ; ln -sf libQtTest.so.4.6.2 libQtTest.so.4 )
( cd usr/lib/qt/lib ; rm -rf libQtCore.so.4 )
( cd usr/lib/qt/lib ; ln -sf libQtCore.so.4.6.2 libQtCore.so.4 )
( cd usr/lib/qt/lib ; rm -rf libQtMultimedia.so.4 )
( cd usr/lib/qt/lib ; ln -sf libQtMultimedia.so.4.6.2 libQtMultimedia.so.4 )
( cd usr/lib/qt/lib ; rm -rf libQtWebKit.so.4.6 )
( cd usr/lib/qt/lib ; ln -sf libQtWebKit.so.4.6.2 libQtWebKit.so.4.6 )
( cd usr/lib/qt/lib ; rm -rf libQtWebKit.so )
( cd usr/lib/qt/lib ; ln -sf libQtWebKit.so.4.6.2 libQtWebKit.so )
( cd usr/lib/qt/lib ; rm -rf libQtCLucene.so.4.6 )
( cd usr/lib/qt/lib ; ln -sf libQtCLucene.so.4.6.2 libQtCLucene.so.4.6 )
( cd usr/lib/qt/lib ; rm -rf libQtScriptTools.so.4.6 )
( cd usr/lib/qt/lib ; ln -sf libQtScriptTools.so.4.6.2 libQtScriptTools.so.4.6 )
( cd usr/lib/qt/lib ; rm -rf libQtGui.so.4.6 )
( cd usr/lib/qt/lib ; ln -sf libQtGui.so.4.6.2 libQtGui.so.4.6 )
( cd usr/lib/qt/lib ; rm -rf libQtSvg.so )
( cd usr/lib/qt/lib ; ln -sf libQtSvg.so.4.6.2 libQtSvg.so )
( cd usr/lib/qt/lib ; rm -rf libQtNetwork.so.4.6 )
( cd usr/lib/qt/lib ; ln -sf libQtNetwork.so.4.6.2 libQtNetwork.so.4.6 )
( cd usr/lib/qt/lib ; rm -rf libQtAssistantClient.so.4.6 )
( cd usr/lib/qt/lib ; ln -sf libQtAssistantClient.so.4.6.2 libQtAssistantClient.so.4.6 )
( cd usr/lib/qt/lib ; rm -rf libQtAssistantClient.so )
( cd usr/lib/qt/lib ; ln -sf libQtAssistantClient.so.4.6.2 libQtAssistantClient.so )
( cd usr/lib/qt/lib ; rm -rf libQt3Support.so )
( cd usr/lib/qt/lib ; ln -sf libQt3Support.so.4.6.2 libQt3Support.so )
( cd usr/lib/qt/lib ; rm -rf libQtDesignerComponents.so.4.6 )
( cd usr/lib/qt/lib ; ln -sf libQtDesignerComponents.so.4.6.2 libQtDesignerComponents.so.4.6 )
( cd usr/lib/qt/lib ; rm -rf libQtSql.so )
( cd usr/lib/qt/lib ; ln -sf libQtSql.so.4.6.2 libQtSql.so )
( cd usr/lib/qt/lib ; rm -rf libQtMultimedia.so )
( cd usr/lib/qt/lib ; ln -sf libQtMultimedia.so.4.6.2 libQtMultimedia.so )
( cd usr/lib/qt/lib ; rm -rf libQtDesignerComponents.so )
( cd usr/lib/qt/lib ; ln -sf libQtDesignerComponents.so.4.6.2 libQtDesignerComponents.so )
( cd usr/lib/qt/lib ; rm -rf libQtScriptTools.so.4 )
( cd usr/lib/qt/lib ; ln -sf libQtScriptTools.so.4.6.2 libQtScriptTools.so.4 )
( cd usr/lib/qt/lib ; rm -rf libQtDBus.so.4.6 )
( cd usr/lib/qt/lib ; ln -sf libQtDBus.so.4.6.2 libQtDBus.so.4.6 )
( cd usr/lib/qt/lib ; rm -rf libQtOpenGL.so.4 )
( cd usr/lib/qt/lib ; ln -sf libQtOpenGL.so.4.6.2 libQtOpenGL.so.4 )
( cd usr/lib/qt/lib ; rm -rf libQtXml.so )
( cd usr/lib/qt/lib ; ln -sf libQtXml.so.4.6.2 libQtXml.so )
( cd usr/lib/qt/lib ; rm -rf libQtCore.so )
( cd usr/lib/qt/lib ; ln -sf libQtCore.so.4.6.2 libQtCore.so )
( cd usr/lib/qt/lib ; rm -rf libQtHelp.so.4 )
( cd usr/lib/qt/lib ; ln -sf libQtHelp.so.4.6.2 libQtHelp.so.4 )
( cd usr/lib/qt/lib ; rm -rf libQtAssistantClient.so.4 )
( cd usr/lib/qt/lib ; ln -sf libQtAssistantClient.so.4.6.2 libQtAssistantClient.so.4 )
( cd usr/lib/qt/lib ; rm -rf libQtCore.so.4.6 )
( cd usr/lib/qt/lib ; ln -sf libQtCore.so.4.6.2 libQtCore.so.4.6 )
( cd usr/lib/qt/lib ; rm -rf libQtXmlPatterns.so.4 )
( cd usr/lib/qt/lib ; ln -sf libQtXmlPatterns.so.4.6.2 libQtXmlPatterns.so.4 )
( cd usr/lib/qt/lib ; rm -rf libQtOpenGL.so.4.6 )
( cd usr/lib/qt/lib ; ln -sf libQtOpenGL.so.4.6.2 libQtOpenGL.so.4.6 )
( cd usr/lib/qt/lib ; rm -rf libQtGui.so.4 )
( cd usr/lib/qt/lib ; ln -sf libQtGui.so.4.6.2 libQtGui.so.4 )
( cd usr/lib/qt/lib ; rm -rf libQtMultimedia.so.4.6 )
( cd usr/lib/qt/lib ; ln -sf libQtMultimedia.so.4.6.2 libQtMultimedia.so.4.6 )
( cd usr/lib/qt/lib ; rm -rf libQtScriptTools.so )
( cd usr/lib/qt/lib ; ln -sf libQtScriptTools.so.4.6.2 libQtScriptTools.so )
( cd usr/lib/qt/lib ; rm -rf libQtNetwork.so )
( cd usr/lib/qt/lib ; ln -sf libQtNetwork.so.4.6.2 libQtNetwork.so )
( cd usr/lib/qt/lib ; rm -rf libQtDBus.so.4 )
( cd usr/lib/qt/lib ; ln -sf libQtDBus.so.4.6.2 libQtDBus.so.4 )
( cd usr/lib/qt/lib ; rm -rf libQtSvg.so.4.6 )
( cd usr/lib/qt/lib ; ln -sf libQtSvg.so.4.6.2 libQtSvg.so.4.6 )
( cd usr/lib/qt/lib ; rm -rf libQtDesigner.so.4.6 )
( cd usr/lib/qt/lib ; ln -sf libQtDesigner.so.4.6.2 libQtDesigner.so.4.6 )
( cd usr/lib/qt/lib ; rm -rf libQtNetwork.so.4 )
( cd usr/lib/qt/lib ; ln -sf libQtNetwork.so.4.6.2 libQtNetwork.so.4 )
( cd usr/lib/qt/lib ; rm -rf libQtScript.so.4.6 )
( cd usr/lib/qt/lib ; ln -sf libQtScript.so.4.6.2 libQtScript.so.4.6 )
( cd usr/lib/qt/lib ; rm -rf libQtCLucene.so.4 )
( cd usr/lib/qt/lib ; ln -sf libQtCLucene.so.4.6.2 libQtCLucene.so.4 )
( cd usr/lib/qt/lib ; rm -rf libQtDesigner.so )
( cd usr/lib/qt/lib ; ln -sf libQtDesigner.so.4.6.2 libQtDesigner.so )
( cd usr/lib/qt/lib ; rm -rf libQtScript.so )
( cd usr/lib/qt/lib ; ln -sf libQtScript.so.4.6.2 libQtScript.so )
( cd usr/lib/qt/lib ; rm -rf libQtXmlPatterns.so.4.6 )
( cd usr/lib/qt/lib ; ln -sf libQtXmlPatterns.so.4.6.2 libQtXmlPatterns.so.4.6 )
( cd usr/lib/qt/lib ; rm -rf libQt3Support.so.4.6 )
( cd usr/lib/qt/lib ; ln -sf libQt3Support.so.4.6.2 libQt3Support.so.4.6 )
( cd usr/lib/qt/lib ; rm -rf libQt3Support.so.4 )
( cd usr/lib/qt/lib ; ln -sf libQt3Support.so.4.6.2 libQt3Support.so.4 )
( cd usr/lib/qt/lib ; rm -rf libQtOpenGL.so )
( cd usr/lib/qt/lib ; ln -sf libQtOpenGL.so.4.6.2 libQtOpenGL.so )
( cd usr/lib/qt/lib ; rm -rf libQtHelp.so.4.6 )
( cd usr/lib/qt/lib ; ln -sf libQtHelp.so.4.6.2 libQtHelp.so.4.6 )
( cd usr/lib/qt/lib ; rm -rf libQtSql.so.4.6 )
( cd usr/lib/qt/lib ; ln -sf libQtSql.so.4.6.2 libQtSql.so.4.6 )
( cd usr/lib/qt/lib ; rm -rf libQtDesignerComponents.so.4 )
( cd usr/lib/qt/lib ; ln -sf libQtDesignerComponents.so.4.6.2 libQtDesignerComponents.so.4 )
( cd usr/lib/qt/lib ; rm -rf libQtCLucene.so )
( cd usr/lib/qt/lib ; ln -sf libQtCLucene.so.4.6.2 libQtCLucene.so )
( cd usr/lib/qt/lib ; rm -rf libQtHelp.so )
( cd usr/lib/qt/lib ; ln -sf libQtHelp.so.4.6.2 libQtHelp.so )
( cd usr/lib/qt/lib ; rm -rf libQtDBus.so )
( cd usr/lib/qt/lib ; ln -sf libQtDBus.so.4.6.2 libQtDBus.so )
( cd usr/lib/qt/lib ; rm -rf libQtDesigner.so.4 )
( cd usr/lib/qt/lib ; ln -sf libQtDesigner.so.4.6.2 libQtDesigner.so.4 )
( cd usr/lib/qt/lib ; rm -rf libQtScript.so.4 )
( cd usr/lib/qt/lib ; ln -sf libQtScript.so.4.6.2 libQtScript.so.4 )
( cd usr/lib/qt/lib ; rm -rf libQtXmlPatterns.so )
( cd usr/lib/qt/lib ; ln -sf libQtXmlPatterns.so.4.6.2 libQtXmlPatterns.so )
( cd usr/lib/qt/lib ; rm -rf libQtSql.so.4 )
( cd usr/lib/qt/lib ; ln -sf libQtSql.so.4.6.2 libQtSql.so.4 )
( cd usr/lib/qt/lib ; rm -rf libQtGui.so )
( cd usr/lib/qt/lib ; ln -sf libQtGui.so.4.6.2 libQtGui.so )
( cd usr/lib/qt/lib ; rm -rf libQtXml.so.4.6 )
( cd usr/lib/qt/lib ; ln -sf libQtXml.so.4.6.2 libQtXml.so.4.6 )
( cd usr/lib ; rm -rf libQtMultimedia.so.4.6.2 )
( cd usr/lib ; ln -sf qt/lib/libQtMultimedia.so.4.6.2 libQtMultimedia.so.4.6.2 )
( cd usr/lib ; rm -rf libQtNetwork.so )
( cd usr/lib ; ln -sf qt/lib/libQtNetwork.so libQtNetwork.so )
( cd usr/lib ; rm -rf libQtDBus.so.4 )
( cd usr/lib ; ln -sf qt/lib/libQtDBus.so.4 libQtDBus.so.4 )
( cd usr/lib ; rm -rf libQtSql.so.4.6.2 )
( cd usr/lib ; ln -sf qt/lib/libQtSql.so.4.6.2 libQtSql.so.4.6.2 )
( cd usr/lib ; rm -rf libQtSvg.so.4.6 )
( cd usr/lib ; ln -sf qt/lib/libQtSvg.so.4.6 libQtSvg.so.4.6 )
( cd usr/lib ; rm -rf libQtDesigner.so.4.6 )
( cd usr/lib ; ln -sf qt/lib/libQtDesigner.so.4.6 libQtDesigner.so.4.6 )
( cd usr/lib ; rm -rf libQtNetwork.so.4 )
( cd usr/lib ; ln -sf qt/lib/libQtNetwork.so.4 libQtNetwork.so.4 )
( cd usr/lib ; rm -rf libQtScript.so.4.6 )
( cd usr/lib ; ln -sf qt/lib/libQtScript.so.4.6 libQtScript.so.4.6 )
( cd usr/lib ; rm -rf libQtNetwork.so.4.6.2 )
( cd usr/lib ; ln -sf qt/lib/libQtNetwork.so.4.6.2 libQtNetwork.so.4.6.2 )
( cd usr/lib ; rm -rf libQtScriptTools.so.4.6.2 )
( cd usr/lib ; ln -sf qt/lib/libQtScriptTools.so.4.6.2 libQtScriptTools.so.4.6.2 )
( cd usr/lib ; rm -rf libQtCLucene.so.4 )
( cd usr/lib ; ln -sf qt/lib/libQtCLucene.so.4 libQtCLucene.so.4 )
( cd usr/lib ; rm -rf libQtDesigner.so )
( cd usr/lib ; ln -sf qt/lib/libQtDesigner.so libQtDesigner.so )
( cd usr/lib ; rm -rf libQtScript.so )
( cd usr/lib ; ln -sf qt/lib/libQtScript.so libQtScript.so )
( cd usr/lib ; rm -rf libQtGui.so.4.6.2 )
( cd usr/lib ; ln -sf qt/lib/libQtGui.so.4.6.2 libQtGui.so.4.6.2 )
( cd usr/lib ; rm -rf libQtAssistantClient.so.4.6.2 )
( cd usr/lib ; ln -sf qt/lib/libQtAssistantClient.so.4.6.2 libQtAssistantClient.so.4.6.2 )
( cd usr/lib ; rm -rf libQtXmlPatterns.so.4.6 )
( cd usr/lib ; ln -sf qt/lib/libQtXmlPatterns.so.4.6 libQtXmlPatterns.so.4.6 )
( cd usr/lib ; rm -rf libQt3Support.so.4.6 )
( cd usr/lib ; ln -sf qt/lib/libQt3Support.so.4.6 libQt3Support.so.4.6 )
( cd usr/lib ; rm -rf libQtCore.so.4.6.2 )
( cd usr/lib ; ln -sf qt/lib/libQtCore.so.4.6.2 libQtCore.so.4.6.2 )
( cd usr/lib ; rm -rf libQt3Support.so.4 )
( cd usr/lib ; ln -sf qt/lib/libQt3Support.so.4 libQt3Support.so.4 )
( cd usr/lib/pkgconfig ; rm -rf QtXmlPatterns.pc )
( cd usr/lib/pkgconfig ; ln -sf /usr/lib/qt/lib/pkgconfig/QtXmlPatterns.pc QtXmlPatterns.pc )
( cd usr/lib/pkgconfig ; rm -rf QtTest.pc )
( cd usr/lib/pkgconfig ; ln -sf /usr/lib/qt/lib/pkgconfig/QtTest.pc QtTest.pc )
( cd usr/lib/pkgconfig ; rm -rf QtXml.pc )
( cd usr/lib/pkgconfig ; ln -sf /usr/lib/qt/lib/pkgconfig/QtXml.pc QtXml.pc )
( cd usr/lib/pkgconfig ; rm -rf Qt3Support.pc )
( cd usr/lib/pkgconfig ; ln -sf /usr/lib/qt/lib/pkgconfig/Qt3Support.pc Qt3Support.pc )
( cd usr/lib/pkgconfig ; rm -rf QtDBus.pc )
( cd usr/lib/pkgconfig ; ln -sf /usr/lib/qt/lib/pkgconfig/QtDBus.pc QtDBus.pc )
( cd usr/lib/pkgconfig ; rm -rf QtSql.pc )
( cd usr/lib/pkgconfig ; ln -sf /usr/lib/qt/lib/pkgconfig/QtSql.pc QtSql.pc )
( cd usr/lib/pkgconfig ; rm -rf QtScriptTools.pc )
( cd usr/lib/pkgconfig ; ln -sf /usr/lib/qt/lib/pkgconfig/QtScriptTools.pc QtScriptTools.pc )
( cd usr/lib/pkgconfig ; rm -rf QtNetwork.pc )
( cd usr/lib/pkgconfig ; ln -sf /usr/lib/qt/lib/pkgconfig/QtNetwork.pc QtNetwork.pc )
( cd usr/lib/pkgconfig ; rm -rf QtOpenGL.pc )
( cd usr/lib/pkgconfig ; ln -sf /usr/lib/qt/lib/pkgconfig/QtOpenGL.pc QtOpenGL.pc )
( cd usr/lib/pkgconfig ; rm -rf QtSvg.pc )
( cd usr/lib/pkgconfig ; ln -sf /usr/lib/qt/lib/pkgconfig/QtSvg.pc QtSvg.pc )
( cd usr/lib/pkgconfig ; rm -rf QtHelp.pc )
( cd usr/lib/pkgconfig ; ln -sf /usr/lib/qt/lib/pkgconfig/QtHelp.pc QtHelp.pc )
( cd usr/lib/pkgconfig ; rm -rf QtCore.pc )
( cd usr/lib/pkgconfig ; ln -sf /usr/lib/qt/lib/pkgconfig/QtCore.pc QtCore.pc )
( cd usr/lib/pkgconfig ; rm -rf QtAssistantClient.pc )
( cd usr/lib/pkgconfig ; ln -sf /usr/lib/qt/lib/pkgconfig/QtAssistantClient.pc QtAssistantClient.pc )
( cd usr/lib/pkgconfig ; rm -rf QtUiTools.pc )
( cd usr/lib/pkgconfig ; ln -sf /usr/lib/qt/lib/pkgconfig/QtUiTools.pc QtUiTools.pc )
( cd usr/lib/pkgconfig ; rm -rf QtGui.pc )
( cd usr/lib/pkgconfig ; ln -sf /usr/lib/qt/lib/pkgconfig/QtGui.pc QtGui.pc )
( cd usr/lib/pkgconfig ; rm -rf QtMultimedia.pc )
( cd usr/lib/pkgconfig ; ln -sf /usr/lib/qt/lib/pkgconfig/QtMultimedia.pc QtMultimedia.pc )
( cd usr/lib/pkgconfig ; rm -rf QtDesigner.pc )
( cd usr/lib/pkgconfig ; ln -sf /usr/lib/qt/lib/pkgconfig/QtDesigner.pc QtDesigner.pc )
( cd usr/lib/pkgconfig ; rm -rf QtDesignerComponents.pc )
( cd usr/lib/pkgconfig ; ln -sf /usr/lib/qt/lib/pkgconfig/QtDesignerComponents.pc QtDesignerComponents.pc )
( cd usr/lib/pkgconfig ; rm -rf QtCLucene.pc )
( cd usr/lib/pkgconfig ; ln -sf /usr/lib/qt/lib/pkgconfig/QtCLucene.pc QtCLucene.pc )
( cd usr/lib/pkgconfig ; rm -rf QtWebKit.pc )
( cd usr/lib/pkgconfig ; ln -sf /usr/lib/qt/lib/pkgconfig/QtWebKit.pc QtWebKit.pc )
( cd usr/lib/pkgconfig ; rm -rf QtScript.pc )
( cd usr/lib/pkgconfig ; ln -sf /usr/lib/qt/lib/pkgconfig/QtScript.pc QtScript.pc )
( cd usr/lib ; rm -rf libQtHelp.so.4.6.2 )
( cd usr/lib ; ln -sf qt/lib/libQtHelp.so.4.6.2 libQtHelp.so.4.6.2 )
( cd usr/lib ; rm -rf libQtOpenGL.so )
( cd usr/lib ; ln -sf qt/lib/libQtOpenGL.so libQtOpenGL.so )
( cd usr/lib ; rm -rf libQtHelp.so.4.6 )
( cd usr/lib ; ln -sf qt/lib/libQtHelp.so.4.6 libQtHelp.so.4.6 )
( cd usr/lib ; rm -rf libQtSql.so.4.6 )
( cd usr/lib ; ln -sf qt/lib/libQtSql.so.4.6 libQtSql.so.4.6 )
( cd usr/lib ; rm -rf libQtDesigner.so.4.6.2 )
( cd usr/lib ; ln -sf qt/lib/libQtDesigner.so.4.6.2 libQtDesigner.so.4.6.2 )
( cd usr/lib ; rm -rf libQtDesignerComponents.so.4 )
( cd usr/lib ; ln -sf qt/lib/libQtDesignerComponents.so.4 libQtDesignerComponents.so.4 )
( cd usr/lib ; rm -rf libQtCLucene.so )
( cd usr/lib ; ln -sf qt/lib/libQtCLucene.so libQtCLucene.so )
( cd usr/lib ; rm -rf libQtHelp.so )
( cd usr/lib ; ln -sf qt/lib/libQtHelp.so libQtHelp.so )
( cd usr/lib ; rm -rf libQtDBus.so )
( cd usr/lib ; ln -sf qt/lib/libQtDBus.so libQtDBus.so )
( cd usr/lib ; rm -rf libQtDesigner.so.4 )
( cd usr/lib ; ln -sf qt/lib/libQtDesigner.so.4 libQtDesigner.so.4 )
( cd usr/lib ; rm -rf libQtSvg.so.4.6.2 )
( cd usr/lib ; ln -sf qt/lib/libQtSvg.so.4.6.2 libQtSvg.so.4.6.2 )
( cd usr/lib ; rm -rf libQtScript.so.4 )
( cd usr/lib ; ln -sf qt/lib/libQtScript.so.4 libQtScript.so.4 )
( cd usr/lib ; rm -rf libQtXmlPatterns.so )
( cd usr/lib ; ln -sf qt/lib/libQtXmlPatterns.so libQtXmlPatterns.so )
( cd usr/lib ; rm -rf libQtSql.so.4 )
( cd usr/lib ; ln -sf qt/lib/libQtSql.so.4 libQtSql.so.4 )
( cd usr/lib ; rm -rf libQtDBus.so.4.6.2 )
( cd usr/lib ; ln -sf qt/lib/libQtDBus.so.4.6.2 libQtDBus.so.4.6.2 )
( cd usr/lib ; rm -rf libQtDesignerComponents.so.4.6.2 )
( cd usr/lib ; ln -sf qt/lib/libQtDesignerComponents.so.4.6.2 libQtDesignerComponents.so.4.6.2 )
( cd usr/lib ; rm -rf libQtGui.so )
( cd usr/lib ; ln -sf qt/lib/libQtGui.so libQtGui.so )
( cd usr/lib ; rm -rf libQtTest.so.4.6.2 )
( cd usr/lib ; ln -sf qt/lib/libQtTest.so.4.6.2 libQtTest.so.4.6.2 )
( cd usr/lib ; rm -rf libQtXml.so.4.6 )
( cd usr/lib ; ln -sf qt/lib/libQtXml.so.4.6 libQtXml.so.4.6 )
# Package readline-5.2-i486-4
( cd usr/lib ; rm -rf libreadline.so.5 )
( cd usr/lib ; ln -sf libreadline.so.5.2 libreadline.so.5 )
( cd usr/lib ; rm -rf libreadline.so )
( cd usr/lib ; ln -sf libreadline.so.5 libreadline.so )
( cd usr/lib ; rm -rf libhistory.so )
( cd usr/lib ; ln -sf libhistory.so.5 libhistory.so )
( cd usr/lib ; rm -rf libhistory.so.5 )
( cd usr/lib ; ln -sf libhistory.so.5.2 libhistory.so.5 )
# Package sdl-1.2.14-i486-2
( cd usr/lib ; rm -rf libSDL_mixer.so )
( cd usr/lib ; ln -sf libSDL_mixer-1.2.so.0.10.1 libSDL_mixer.so )
( cd usr/lib ; rm -rf libSDL.so )
( cd usr/lib ; ln -sf libSDL-1.2.so.0.11.3 libSDL.so )
( cd usr/lib ; rm -rf libSDL_ttf.so )
( cd usr/lib ; ln -sf libSDL_ttf-2.0.so.0.6.3 libSDL_ttf.so )
( cd usr/lib ; rm -rf libSDL_ttf-2.0.so.0 )
( cd usr/lib ; ln -sf libSDL_ttf-2.0.so.0.6.3 libSDL_ttf-2.0.so.0 )
( cd usr/lib ; rm -rf libSDL-1.2.so.0 )
( cd usr/lib ; ln -sf libSDL-1.2.so.0.11.3 libSDL-1.2.so.0 )
( cd usr/lib ; rm -rf libSDL_image-1.2.so.0 )
( cd usr/lib ; ln -sf libSDL_image-1.2.so.0.8.2 libSDL_image-1.2.so.0 )
( cd usr/lib ; rm -rf libSDL_net.so )
( cd usr/lib ; ln -sf libSDL_net-1.2.so.0.0.7 libSDL_net.so )
( cd usr/lib ; rm -rf libSDL_mixer-1.2.so.0 )
( cd usr/lib ; ln -sf libSDL_mixer-1.2.so.0.10.1 libSDL_mixer-1.2.so.0 )
( cd usr/lib ; rm -rf libSDL_image.so )
( cd usr/lib ; ln -sf libSDL_image-1.2.so.0.8.2 libSDL_image.so )
( cd usr/lib ; rm -rf libSDL_net-1.2.so.0 )
( cd usr/lib ; ln -sf libSDL_net-1.2.so.0.0.7 libSDL_net-1.2.so.0 )
# Package zlib-1.2.3-i486-2
( cd usr/lib ; rm -rf libz.so )
( cd usr/lib ; ln -sf libz.so.1.2.3 libz.so )
( cd usr/lib ; rm -rf libz.so.1 )
( cd usr/lib ; ln -sf libz.so.1.2.3 libz.so.1 )
# Package gtk+2-2.18.9-i486-1
config() {
  NEW="$1"
  OLD="`dirname $NEW`/`basename $NEW .new`"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "`cat $OLD | md5sum`" = "`cat $NEW | md5sum`" ]; then # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}
if [ -d etc/gtk-2.0/i486-slackware-linux ]; then
  config etc/gtk-2.0/i486-slackware-linux/im-multipress.conf.new
elif [ -d etc/gtk-2.0/i486-slackware-linux ]; then
  config etc/gtk-2.0/i486-slackware-linux/im-multipress.conf.new
elif [ -d etc/gtk-2.0/*-slackware-linux ]; then
  config etc/gtk-2.0/*-slackware-linux/im-multipress.conf.new
fi

# Since the use of icon caching is optional, and has to be kept in sync
# somehow (like a "registry" through a cron job, or whatever, I tend to
# think the user should be the one to choose if they really want to set
# this up or not:
#
# Example:
#for dir in /usr/share/icons/* ; do
#  if [ -d $dir ]; then
#    /usr/bin/gtk-update-icon-cache -f -t $dir 1> /dev/null 2> /dev/null
#  fi
#done
mkdir -p etc/gtk-2.0

chroot . rm -f /usr/share/icons/*/icon-theme.cache 1> /dev/null 2> /dev/null

# Run this if we are on an installed system.  Otherwise it will be
# handled on first boot.
if [ -x /usr/bin/update-gtk-immodules-2.0 ]; then
  /usr/bin/update-gtk-immodules
fi

( cd usr/lib ; rm -rf libgailutil.so )
( cd usr/lib ; ln -sf libgailutil.so.18.0.1 libgailutil.so )
( cd usr/lib ; rm -rf libgdk-x11-2.0.so )
( cd usr/lib ; ln -sf libgdk-x11-2.0.so.0.1800.9 libgdk-x11-2.0.so )
( cd usr/lib ; rm -rf libgdk_pixbuf_xlib-2.0.so )
( cd usr/lib ; ln -sf libgdk_pixbuf_xlib-2.0.so.0.1800.9 libgdk_pixbuf_xlib-2.0.so )
( cd usr/lib ; rm -rf libgailutil.so.18 )
( cd usr/lib ; ln -sf libgailutil.so.18.0.1 libgailutil.so.18 )
( cd usr/lib ; rm -rf libgdk-x11-2.0.so.0 )
( cd usr/lib ; ln -sf libgdk-x11-2.0.so.0.1800.9 libgdk-x11-2.0.so.0 )
( cd usr/lib ; rm -rf libgdk_pixbuf-2.0.so.0 )
( cd usr/lib ; ln -sf libgdk_pixbuf-2.0.so.0.1800.9 libgdk_pixbuf-2.0.so.0 )
( cd usr/lib ; rm -rf libgdk_pixbuf_xlib-2.0.so.0 )
( cd usr/lib ; ln -sf libgdk_pixbuf_xlib-2.0.so.0.1800.9 libgdk_pixbuf_xlib-2.0.so.0 )
( cd usr/lib ; rm -rf libgtk-x11-2.0.so )
( cd usr/lib ; ln -sf libgtk-x11-2.0.so.0.1800.9 libgtk-x11-2.0.so )
( cd usr/lib ; rm -rf libgdk_pixbuf-2.0.so )
( cd usr/lib ; ln -sf libgdk_pixbuf-2.0.so.0.1800.9 libgdk_pixbuf-2.0.so )
( cd usr/lib ; rm -rf libgtk-x11-2.0.so.0 )
( cd usr/lib ; ln -sf libgtk-x11-2.0.so.0.1800.9 libgtk-x11-2.0.so.0 )
# Package pango-1.26.2-i486-1
( cd usr/lib ; rm -rf libpangox-1.0.so )
( cd usr/lib ; ln -sf libpangox-1.0.so.0.2600.2 libpangox-1.0.so )
( cd usr/lib ; rm -rf libpangocairo-1.0.so )
( cd usr/lib ; ln -sf libpangocairo-1.0.so.0.2600.2 libpangocairo-1.0.so )
( cd usr/lib ; rm -rf libpango-1.0.so.0 )
( cd usr/lib ; ln -sf libpango-1.0.so.0.2600.2 libpango-1.0.so.0 )
( cd usr/lib ; rm -rf libpangoxft-1.0.so )
( cd usr/lib ; ln -sf libpangoxft-1.0.so.0.2600.2 libpangoxft-1.0.so )
( cd usr/lib ; rm -rf libpango-1.0.so )
( cd usr/lib ; ln -sf libpango-1.0.so.0.2600.2 libpango-1.0.so )
( cd usr/lib ; rm -rf libpangoft2-1.0.so.0 )
( cd usr/lib ; ln -sf libpangoft2-1.0.so.0.2600.2 libpangoft2-1.0.so.0 )
( cd usr/lib ; rm -rf libpangox-1.0.so.0 )
( cd usr/lib ; ln -sf libpangox-1.0.so.0.2600.2 libpangox-1.0.so.0 )
( cd usr/lib ; rm -rf libpangoxft-1.0.so.0 )
( cd usr/lib ; ln -sf libpangoxft-1.0.so.0.2600.2 libpangoxft-1.0.so.0 )
( cd usr/lib ; rm -rf libpangoft2-1.0.so )
( cd usr/lib ; ln -sf libpangoft2-1.0.so.0.2600.2 libpangoft2-1.0.so )
( cd usr/lib ; rm -rf libpangocairo-1.0.so.0 )
( cd usr/lib ; ln -sf libpangocairo-1.0.so.0.2600.2 libpangocairo-1.0.so.0 )

# Updating the pango.modules file:
chroot . /sbin/ldconfig 2> /dev/null
if [ -x /usr/bin/update-pango-querymodules ]; then
  /usr/bin/update-pango-querymodules
fi
# Package seamonkey-solibs-2.0.4-i486-1
( cd usr/lib ; rm -rf seamonkey )
( cd usr/lib ; ln -sf seamonkey-2.0.4 seamonkey )
# Package curl-7.20.1-i486-1
( cd usr/lib ; rm -rf libcurl.so.4 )
( cd usr/lib ; ln -sf libcurl.so.4.2.0 libcurl.so.4 )
( cd usr/lib ; rm -rf libcurl.so )
( cd usr/lib ; ln -sf libcurl.so.4.2.0 libcurl.so )
# Package cyrus-sasl-2.1.23-i486-1
( cd usr/lib ; rm -rf libsasl2.so )
( cd usr/lib ; ln -sf libsasl2.so.2.0.23 libsasl2.so )
( cd usr/lib/sasl2 ; rm -rf libsasldb.so.2 )
( cd usr/lib/sasl2 ; ln -sf libsasldb.so.2.0.23 libsasldb.so.2 )
( cd usr/lib/sasl2 ; rm -rf libplain.so )
( cd usr/lib/sasl2 ; ln -sf libplain.so.2.0.23 libplain.so )
( cd usr/lib/sasl2 ; rm -rf liblogin.so )
( cd usr/lib/sasl2 ; ln -sf liblogin.so.2.0.23 liblogin.so )
( cd usr/lib/sasl2 ; rm -rf libsasldb.so )
( cd usr/lib/sasl2 ; ln -sf libsasldb.so.2.0.23 libsasldb.so )
( cd usr/lib/sasl2 ; rm -rf libcrammd5.so )
( cd usr/lib/sasl2 ; ln -sf libcrammd5.so.2.0.23 libcrammd5.so )
( cd usr/lib/sasl2 ; rm -rf libotp.so )
( cd usr/lib/sasl2 ; ln -sf libotp.so.2.0.23 libotp.so )
( cd usr/lib/sasl2 ; rm -rf libcrammd5.so.2 )
( cd usr/lib/sasl2 ; ln -sf libcrammd5.so.2.0.23 libcrammd5.so.2 )
( cd usr/lib/sasl2 ; rm -rf liblogin.so.2 )
( cd usr/lib/sasl2 ; ln -sf liblogin.so.2.0.23 liblogin.so.2 )
( cd usr/lib/sasl2 ; rm -rf libdigestmd5.so.2 )
( cd usr/lib/sasl2 ; ln -sf libdigestmd5.so.2.0.23 libdigestmd5.so.2 )
( cd usr/lib/sasl2 ; rm -rf libotp.so.2 )
( cd usr/lib/sasl2 ; ln -sf libotp.so.2.0.23 libotp.so.2 )
( cd usr/lib/sasl2 ; rm -rf libplain.so.2 )
( cd usr/lib/sasl2 ; ln -sf libplain.so.2.0.23 libplain.so.2 )
( cd usr/lib/sasl2 ; rm -rf libdigestmd5.so )
( cd usr/lib/sasl2 ; ln -sf libdigestmd5.so.2.0.23 libdigestmd5.so )
( cd usr/lib ; rm -rf libsasl2.so.2 )
( cd usr/lib ; ln -sf libsasl2.so.2.0.23 libsasl2.so.2 )
# Package gnutls-2.8.6-i486-1
( cd usr/lib ; rm -rf libgnutls-openssl.so )
( cd usr/lib ; ln -sf libgnutls-openssl.so.26.14.12 libgnutls-openssl.so )
( cd usr/lib ; rm -rf libguile-gnutls-v-1.so.0 )
( cd usr/lib ; ln -sf libguile-gnutls-v-1.so.0.0.0 libguile-gnutls-v-1.so.0 )
( cd usr/lib ; rm -rf libguile-gnutls-extra-v-1.so.0 )
( cd usr/lib ; ln -sf libguile-gnutls-extra-v-1.so.0.0.0 libguile-gnutls-extra-v-1.so.0 )
( cd usr/lib ; rm -rf libgnutlsxx.so )
( cd usr/lib ; ln -sf libgnutlsxx.so.26.14.12 libgnutlsxx.so )
( cd usr/lib ; rm -rf libguile-gnutls-extra-v-1.so )
( cd usr/lib ; ln -sf libguile-gnutls-extra-v-1.so.0.0.0 libguile-gnutls-extra-v-1.so )
( cd usr/lib ; rm -rf libgnutls.so )
( cd usr/lib ; ln -sf libgnutls.so.26.14.12 libgnutls.so )
( cd usr/lib ; rm -rf libgnutlsxx.so.26 )
( cd usr/lib ; ln -sf libgnutlsxx.so.26.14.12 libgnutlsxx.so.26 )
( cd usr/lib ; rm -rf libgnutls-extra.so.26 )
( cd usr/lib ; ln -sf libgnutls-extra.so.26.14.12 libgnutls-extra.so.26 )
( cd usr/lib ; rm -rf libgnutls-openssl.so.26 )
( cd usr/lib ; ln -sf libgnutls-openssl.so.26.14.12 libgnutls-openssl.so.26 )
( cd usr/lib ; rm -rf libguile-gnutls-v-1.so )
( cd usr/lib ; ln -sf libguile-gnutls-v-1.so.0.0.0 libguile-gnutls-v-1.so )
( cd usr/lib ; rm -rf libgnutls.so.26 )
( cd usr/lib ; ln -sf libgnutls.so.26.14.12 libgnutls.so.26 )
( cd usr/lib ; rm -rf libgnutls-extra.so )
( cd usr/lib ; ln -sf libgnutls-extra.so.26.14.12 libgnutls-extra.so )
# Package libgcrypt-1.4.5-i486-2
( cd lib ; rm -rf libgcrypt.so.11 )
( cd lib ; ln -sf libgcrypt.so.11.5.3 libgcrypt.so.11 )
( cd usr/lib ; rm -rf libgcrypt.so.11 )
( cd usr/lib ; ln -sf libgcrypt.so.11.5.3 libgcrypt.so.11 )
( cd usr/lib ; rm -rf libgcrypt.so )
( cd usr/lib ; ln -sf libgcrypt.so.11.5.3 libgcrypt.so )
( cd usr/lib ; rm -rf libgcrypt.so.11.5.3 )
( cd usr/lib ; ln -sf ../../lib/libgcrypt.so.11.5.3 libgcrypt.so.11.5.3 )
# Package libgpg-error-1.7-i486-2
( cd lib ; rm -rf libgpg-error.so.0 )
( cd lib ; ln -sf libgpg-error.so.0.5.0 libgpg-error.so.0 )
( cd usr/lib ; rm -rf libgpg-error.so.0.5.0 )
( cd usr/lib ; ln -sf ../../lib/libgpg-error.so.0.5.0 libgpg-error.so.0.5.0 )
( cd usr/lib ; rm -rf libgpg-error.so.0 )
( cd usr/lib ; ln -sf libgpg-error.so.0.5.0 libgpg-error.so.0 )
( cd usr/lib ; rm -rf libgpg-error.so )
( cd usr/lib ; ln -sf libgpg-error.so.0.5.0 libgpg-error.so )
# Package openldap-client-2.4.21-i486-1
( cd usr/bin/32 ; rm -rf ldapadd )
( cd usr/bin/32 ; ln -sf ldapmodify ldapadd )
( cd usr/lib ; rm -rf libldap_r-2.4.so.2 )
( cd usr/lib ; ln -sf libldap_r-2.4.so.2.5.4 libldap_r-2.4.so.2 )
( cd usr/lib ; rm -rf libldap-2.4.so.2 )
( cd usr/lib ; ln -sf libldap-2.4.so.2.5.4 libldap-2.4.so.2 )
( cd usr/lib ; rm -rf liblber.so )
( cd usr/lib ; ln -sf liblber-2.4.so.2.5.4 liblber.so )
( cd usr/lib ; rm -rf liblber-2.4.so.2 )
( cd usr/lib ; ln -sf liblber-2.4.so.2.5.4 liblber-2.4.so.2 )
( cd usr/lib ; rm -rf libldap_r.so )
( cd usr/lib ; ln -sf libldap_r-2.4.so.2.5.4 libldap_r.so )
( cd usr/lib ; rm -rf libldap.so )
( cd usr/lib ; ln -sf libldap-2.4.so.2.5.4 libldap.so )
# Package openssl-0.9.8n-i486-1
( cd lib ; rm -rf libcrypto.so.0 )
( cd lib ; ln -sf libcrypto.so.0.9.8 libcrypto.so.0 )
( cd lib ; rm -rf libssl.so.0 )
( cd lib ; ln -sf libssl.so.0.9.8 libssl.so.0 )
( cd usr/lib ; rm -rf libcrypto.so.0 )
( cd usr/lib ; ln -sf libcrypto.so.0.9.8 libcrypto.so.0 )
( cd usr/lib ; rm -rf libssl.so )
( cd usr/lib ; ln -sf libssl.so.0.9.8 libssl.so )
( cd usr/lib ; rm -rf libcrypto.so )
( cd usr/lib ; ln -sf libcrypto.so.0.9.8 libcrypto.so )
( cd usr/lib ; rm -rf libcrypto.so.0.9.8 )
( cd usr/lib ; ln -sf ../../lib/libcrypto.so.0.9.8 libcrypto.so.0.9.8 )
( cd usr/lib ; rm -rf libssl.so.0.9.8 )
( cd usr/lib ; ln -sf ../../lib/libssl.so.0.9.8 libssl.so.0.9.8 )
( cd usr/lib ; rm -rf libssl.so.0 )
( cd usr/lib ; ln -sf libssl.so.0.9.8 libssl.so.0 )
# Package libX11-1.3.3-i486-1
( cd usr/lib ; rm -rf libX11-xcb.so.1 )
( cd usr/lib ; ln -sf libX11-xcb.so.1.0.0 libX11-xcb.so.1 )
( cd usr/lib ; rm -rf libX11-xcb.so )
( cd usr/lib ; ln -sf libX11-xcb.so.1.0.0 libX11-xcb.so )
( cd usr/lib ; rm -rf libX11.so )
( cd usr/lib ; ln -sf libX11.so.6.3.0 libX11.so )
( cd usr/lib ; rm -rf libX11.so.6 )
( cd usr/lib ; ln -sf libX11.so.6.3.0 libX11.so.6 )
# Package libXScrnSaver-1.2.0-i486-1
( cd usr/lib ; rm -rf libXss.so.1 )
( cd usr/lib ; ln -sf libXss.so.1.0.0 libXss.so.1 )
( cd usr/lib ; rm -rf libXss.so )
( cd usr/lib ; ln -sf libXss.so.1.0.0 libXss.so )
# Package libXTrap-1.0.0-i486-2
( cd usr/lib ; rm -rf libXTrap.so.6 )
( cd usr/lib ; ln -sf libXTrap.so.6.4.0 libXTrap.so.6 )
( cd usr/lib ; rm -rf libXTrap.so )
( cd usr/lib ; ln -sf libXTrap.so.6.4.0 libXTrap.so )
# Package libXau-1.0.5-i486-1
( cd usr/lib ; rm -rf libXau.so )
( cd usr/lib ; ln -sf libXau.so.6.0.0 libXau.so )
( cd usr/lib ; rm -rf libXau.so.6 )
( cd usr/lib ; ln -sf libXau.so.6.0.0 libXau.so.6 )
# Package libXaw-1.0.7-i486-1
( cd usr/lib ; rm -rf libXaw7.so )
( cd usr/lib ; ln -sf libXaw7.so.7.0.0 libXaw7.so )
( cd usr/lib ; rm -rf libXaw.so.8 )
( cd usr/lib ; ln -sf libXaw.so.7 libXaw.so.8 )
( cd usr/lib ; rm -rf libXaw.so.7 )
( cd usr/lib ; ln -sf libXaw7.so.7 libXaw.so.7 )
( cd usr/lib ; rm -rf libXaw.so.6 )
( cd usr/lib ; ln -sf libXaw6.so.6 libXaw.so.6 )
( cd usr/lib ; rm -rf libXaw7.so.7 )
( cd usr/lib ; ln -sf libXaw7.so.7.0.0 libXaw7.so.7 )
( cd usr/lib ; rm -rf libXaw.so )
( cd usr/lib ; ln -sf libXaw7.so libXaw.so )
( cd usr/lib ; rm -rf libXaw6.so.6 )
( cd usr/lib ; ln -sf libXaw6.so.6.0.1 libXaw6.so.6 )
( cd usr/lib ; rm -rf libXaw6.so )
( cd usr/lib ; ln -sf libXaw6.so.6.0.1 libXaw6.so )
# Package libXcomposite-0.4.1-i486-1
( cd usr/lib ; rm -rf libXcomposite.so.1 )
( cd usr/lib ; ln -sf libXcomposite.so.1.0.0 libXcomposite.so.1 )
( cd usr/lib ; rm -rf libXcomposite.so )
( cd usr/lib ; ln -sf libXcomposite.so.1.0.0 libXcomposite.so )
# Package libXcursor-1.1.10-i486-1
( cd usr/lib ; rm -rf libXcursor.so )
( cd usr/lib ; ln -sf libXcursor.so.1.0.2 libXcursor.so )
( cd usr/lib ; rm -rf libXcursor.so.1 )
( cd usr/lib ; ln -sf libXcursor.so.1.0.2 libXcursor.so.1 )
# Package libXdamage-1.1.2-i486-1
( cd usr/lib ; rm -rf libXdamage.so.1 )
( cd usr/lib ; ln -sf libXdamage.so.1.1.0 libXdamage.so.1 )
( cd usr/lib ; rm -rf libXdamage.so )
( cd usr/lib ; ln -sf libXdamage.so.1.1.0 libXdamage.so )
# Package libXdmcp-1.0.3-i486-1
( cd usr/lib ; rm -rf libXdmcp.so.6 )
( cd usr/lib ; ln -sf libXdmcp.so.6.0.0 libXdmcp.so.6 )
( cd usr/lib ; rm -rf libXdmcp.so )
( cd usr/lib ; ln -sf libXdmcp.so.6.0.0 libXdmcp.so )
# Package libXevie-1.0.2-i486-2
( cd usr/lib ; rm -rf libXevie.so )
( cd usr/lib ; ln -sf libXevie.so.1.0.0 libXevie.so )
( cd usr/lib ; rm -rf libXevie.so.1 )
( cd usr/lib ; ln -sf libXevie.so.1.0.0 libXevie.so.1 )
# Package libXext-1.1-i486-1
( cd usr/lib ; rm -rf libXext.so.6 )
( cd usr/lib ; ln -sf libXext.so.6.4.0 libXext.so.6 )
( cd usr/lib ; rm -rf libXext.so )
( cd usr/lib ; ln -sf libXext.so.6.4.0 libXext.so )
# Package libXfixes-4.0.4-i486-1
( cd usr/lib ; rm -rf libXfixes.so.3 )
( cd usr/lib ; ln -sf libXfixes.so.3.1.0 libXfixes.so.3 )
( cd usr/lib ; rm -rf libXfixes.so )
( cd usr/lib ; ln -sf libXfixes.so.3.1.0 libXfixes.so )
# Package libXfont-1.4.1-i486-1
( cd usr/lib ; rm -rf libXfont.so )
( cd usr/lib ; ln -sf libXfont.so.1.4.1 libXfont.so )
( cd usr/lib ; rm -rf libXfont.so.1 )
( cd usr/lib ; ln -sf libXfont.so.1.4.1 libXfont.so.1 )
# Package libXfontcache-1.0.5-i486-1
( cd usr/lib ; rm -rf libXfontcache.so )
( cd usr/lib ; ln -sf libXfontcache.so.1.0.0 libXfontcache.so )
( cd usr/lib ; rm -rf libXfontcache.so.1 )
( cd usr/lib ; ln -sf libXfontcache.so.1.0.0 libXfontcache.so.1 )
# Package libXft-2.1.14-i486-1
( cd usr/lib ; rm -rf libXft.so )
( cd usr/lib ; ln -sf libXft.so.2.1.13 libXft.so )
( cd usr/lib ; rm -rf libXft.so.2 )
( cd usr/lib ; ln -sf libXft.so.2.1.13 libXft.so.2 )
# Package libXi-1.3-i486-1
( cd usr/lib ; rm -rf libXi.so )
( cd usr/lib ; ln -sf libXi.so.6.1.0 libXi.so )
( cd usr/lib ; rm -rf libXi.so.6 )
( cd usr/lib ; ln -sf libXi.so.6.1.0 libXi.so.6 )
# Package libXinerama-1.1-i486-1
( cd usr/lib ; rm -rf libXinerama.so )
( cd usr/lib ; ln -sf libXinerama.so.1.0.0 libXinerama.so )
( cd usr/lib ; rm -rf libXinerama.so.1 )
( cd usr/lib ; ln -sf libXinerama.so.1.0.0 libXinerama.so.1 )
# Package libXmu-1.0.5-i486-1
( cd usr/lib ; rm -rf libXmuu.so.1 )
( cd usr/lib ; ln -sf libXmuu.so.1.0.0 libXmuu.so.1 )
( cd usr/lib ; rm -rf libXmu.so )
( cd usr/lib ; ln -sf libXmu.so.6.2.0 libXmu.so )
( cd usr/lib ; rm -rf libXmu.so.6 )
( cd usr/lib ; ln -sf libXmu.so.6.2.0 libXmu.so.6 )
( cd usr/lib ; rm -rf libXmuu.so )
( cd usr/lib ; ln -sf libXmuu.so.1.0.0 libXmuu.so )
# Package libXp-1.0.0-i486-2
( cd usr/lib ; rm -rf libXp.so )
( cd usr/lib ; ln -sf libXp.so.6.2.0 libXp.so )
( cd usr/lib ; rm -rf libXp.so.6 )
( cd usr/lib ; ln -sf libXp.so.6.2.0 libXp.so.6 )
# Package libXpm-3.5.8-i486-1
( cd usr/lib ; rm -rf libXpm.so )
( cd usr/lib ; ln -sf libXpm.so.4.11.0 libXpm.so )
( cd usr/lib ; rm -rf libXpm.so.4 )
( cd usr/lib ; ln -sf libXpm.so.4.11.0 libXpm.so.4 )
# Package libXprintUtil-1.0.1-i486-2
( cd usr/lib ; rm -rf libXprintUtil.so.1 )
( cd usr/lib ; ln -sf libXprintUtil.so.1.0.0 libXprintUtil.so.1 )
( cd usr/lib ; rm -rf libXprintUtil.so )
( cd usr/lib ; ln -sf libXprintUtil.so.1.0.0 libXprintUtil.so )
# Package libXrandr-1.3.0-i486-1
( cd usr/lib ; rm -rf libXrandr.so )
( cd usr/lib ; ln -sf libXrandr.so.2.2.0 libXrandr.so )
( cd usr/lib ; rm -rf libXrandr.so.2 )
( cd usr/lib ; ln -sf libXrandr.so.2.2.0 libXrandr.so.2 )
# Package libXrender-0.9.5-i486-1
( cd usr/lib ; rm -rf libXrender.so.1 )
( cd usr/lib ; ln -sf libXrender.so.1.3.0 libXrender.so.1 )
( cd usr/lib ; rm -rf libXrender.so )
( cd usr/lib ; ln -sf libXrender.so.1.3.0 libXrender.so )
# Package libXres-1.0.4-i486-1
( cd usr/lib ; rm -rf libXRes.so )
( cd usr/lib ; ln -sf libXRes.so.1.0.0 libXRes.so )
( cd usr/lib ; rm -rf libXRes.so.1 )
( cd usr/lib ; ln -sf libXRes.so.1.0.0 libXRes.so.1 )
# Package libXt-1.0.8-i486-1
( cd usr/lib ; rm -rf libXt.so )
( cd usr/lib ; ln -sf libXt.so.6.0.0 libXt.so )
( cd usr/lib ; rm -rf libXt.so.6 )
( cd usr/lib ; ln -sf libXt.so.6.0.0 libXt.so.6 )
# Package libXtst-1.1.0-i486-1
( cd usr/lib ; rm -rf libXtst.so.6 )
( cd usr/lib ; ln -sf libXtst.so.6.1.0 libXtst.so.6 )
( cd usr/lib ; rm -rf libXtst.so )
( cd usr/lib ; ln -sf libXtst.so.6.1.0 libXtst.so )
# Package libXv-1.0.5-i486-1
( cd usr/lib ; rm -rf libXv.so.1 )
( cd usr/lib ; ln -sf libXv.so.1.0.0 libXv.so.1 )
( cd usr/lib ; rm -rf libXv.so )
( cd usr/lib ; ln -sf libXv.so.1.0.0 libXv.so )
# Package libXvMC-1.0.5-i486-1
( cd usr/lib ; rm -rf libXvMCW.so.1 )
( cd usr/lib ; ln -sf libXvMCW.so.1.0.0 libXvMCW.so.1 )
( cd usr/lib ; rm -rf libXvMCW.so )
( cd usr/lib ; ln -sf libXvMCW.so.1.0.0 libXvMCW.so )
( cd usr/lib ; rm -rf libXvMC.so.1 )
( cd usr/lib ; ln -sf libXvMC.so.1.0.0 libXvMC.so.1 )
( cd usr/lib ; rm -rf libXvMC.so )
( cd usr/lib ; ln -sf libXvMC.so.1.0.0 libXvMC.so )
# Package libXxf86dga-1.1.1-i486-1
( cd usr/lib ; rm -rf libXxf86dga.so )
( cd usr/lib ; ln -sf libXxf86dga.so.1.0.0 libXxf86dga.so )
( cd usr/lib ; rm -rf libXxf86dga.so.1 )
( cd usr/lib ; ln -sf libXxf86dga.so.1.0.0 libXxf86dga.so.1 )
# Package libXxf86misc-1.0.2-i486-1
( cd usr/lib ; rm -rf libXxf86misc.so.1 )
( cd usr/lib ; ln -sf libXxf86misc.so.1.1.0 libXxf86misc.so.1 )
( cd usr/lib ; rm -rf libXxf86misc.so )
( cd usr/lib ; ln -sf libXxf86misc.so.1.1.0 libXxf86misc.so )
# Package libXxf86vm-1.1.0-i486-1
( cd usr/lib ; rm -rf libXxf86vm.so.1 )
( cd usr/lib ; ln -sf libXxf86vm.so.1.0.0 libXxf86vm.so.1 )
( cd usr/lib ; rm -rf libXxf86vm.so )
( cd usr/lib ; ln -sf libXxf86vm.so.1.0.0 libXxf86vm.so )
# Package libFS-1.0.2-i486-1
( cd usr/lib ; rm -rf libFS.so )
( cd usr/lib ; ln -sf libFS.so.6.0.0 libFS.so )
( cd usr/lib ; rm -rf libFS.so.6 )
( cd usr/lib ; ln -sf libFS.so.6.0.0 libFS.so.6 )
# Package libICE-1.0.6-i486-1
( cd usr/lib ; rm -rf libICE.so.6 )
( cd usr/lib ; ln -sf libICE.so.6.3.0 libICE.so.6 )
( cd usr/lib ; rm -rf libICE.so )
( cd usr/lib ; ln -sf libICE.so.6.3.0 libICE.so )
# Package libSM-1.1.1-i486-1
( cd usr/lib ; rm -rf libSM.so )
( cd usr/lib ; ln -sf libSM.so.6.0.1 libSM.so )
( cd usr/lib ; rm -rf libSM.so.6 )
( cd usr/lib ; ln -sf libSM.so.6.0.1 libSM.so.6 )
# Package libdmx-1.1.0-i486-1
( cd usr/lib ; rm -rf libdmx.so )
( cd usr/lib ; ln -sf libdmx.so.1.0.0 libdmx.so )
( cd usr/lib ; rm -rf libdmx.so.1 )
( cd usr/lib ; ln -sf libdmx.so.1.0.0 libdmx.so.1 )
# Package libdrm-2.4.20-i486-1
( cd usr/lib ; rm -rf libdrm_radeon.so )
( cd usr/lib ; ln -sf libdrm_radeon.so.1.0.0 libdrm_radeon.so )
( cd usr/lib ; rm -rf libdrm.so.2 )
( cd usr/lib ; ln -sf libdrm.so.2.4.0 libdrm.so.2 )
( cd usr/lib ; rm -rf libdrm_radeon.so.1 )
( cd usr/lib ; ln -sf libdrm_radeon.so.1.0.0 libdrm_radeon.so.1 )
( cd usr/lib ; rm -rf libdrm_nouveau.so )
( cd usr/lib ; ln -sf libdrm_nouveau.so.1.0.0 libdrm_nouveau.so )
( cd usr/lib ; rm -rf libdrm_intel.so.1 )
( cd usr/lib ; ln -sf libdrm_intel.so.1.0.0 libdrm_intel.so.1 )
( cd usr/lib ; rm -rf libdrm_intel.so )
( cd usr/lib ; ln -sf libdrm_intel.so.1.0.0 libdrm_intel.so )
( cd usr/lib ; rm -rf libkms.so )
( cd usr/lib ; ln -sf libkms.so.1.0.0 libkms.so )
( cd usr/lib ; rm -rf libdrm_nouveau.so.1 )
( cd usr/lib ; ln -sf libdrm_nouveau.so.1.0.0 libdrm_nouveau.so.1 )
( cd usr/lib ; rm -rf libdrm.so )
( cd usr/lib ; ln -sf libdrm.so.2.4.0 libdrm.so )
( cd usr/lib ; rm -rf libkms.so.1 )
( cd usr/lib ; ln -sf libkms.so.1.0.0 libkms.so.1 )
# Package libfontenc-1.0.5-i486-1
( cd usr/lib ; rm -rf libfontenc.so )
( cd usr/lib ; ln -sf libfontenc.so.1.0.0 libfontenc.so )
( cd usr/lib ; rm -rf libfontenc.so.1 )
( cd usr/lib ; ln -sf libfontenc.so.1.0.0 libfontenc.so.1 )
# Package libxcb-1.6-i486-1
( cd usr/lib ; rm -rf libxcb-xevie.so )
( cd usr/lib ; ln -sf libxcb-xevie.so.0.0.0 libxcb-xevie.so )
( cd usr/lib ; rm -rf libxcb-xv.so )
( cd usr/lib ; ln -sf libxcb-xv.so.0.0.0 libxcb-xv.so )
( cd usr/lib ; rm -rf libxcb-sync.so.0 )
( cd usr/lib ; ln -sf libxcb-sync.so.0.0.0 libxcb-sync.so.0 )
( cd usr/lib ; rm -rf libxcb-damage.so.0 )
( cd usr/lib ; ln -sf libxcb-damage.so.0.0.0 libxcb-damage.so.0 )
( cd usr/lib ; rm -rf libxcb-shm.so )
( cd usr/lib ; ln -sf libxcb-shm.so.0.0.0 libxcb-shm.so )
( cd usr/lib ; rm -rf libxcb-record.so )
( cd usr/lib ; ln -sf libxcb-record.so.0.0.0 libxcb-record.so )
( cd usr/lib ; rm -rf libxcb-randr.so.0 )
( cd usr/lib ; ln -sf libxcb-randr.so.0.1.0 libxcb-randr.so.0 )
( cd usr/lib ; rm -rf libxcb-shape.so )
( cd usr/lib ; ln -sf libxcb-shape.so.0.0.0 libxcb-shape.so )
( cd usr/lib ; rm -rf libxcb.so.1 )
( cd usr/lib ; ln -sf libxcb.so.1.1.0 libxcb.so.1 )
( cd usr/lib ; rm -rf libxcb-xv.so.0 )
( cd usr/lib ; ln -sf libxcb-xv.so.0.0.0 libxcb-xv.so.0 )
( cd usr/lib ; rm -rf libxcb-dri2.so.0 )
( cd usr/lib ; ln -sf libxcb-dri2.so.0.0.0 libxcb-dri2.so.0 )
( cd usr/lib ; rm -rf libxcb-xlib.so.0 )
( cd usr/lib ; ln -sf libxcb.so.1 libxcb-xlib.so.0 )
( cd usr/lib ; rm -rf libxcb-xinerama.so )
( cd usr/lib ; ln -sf libxcb-xinerama.so.0.0.0 libxcb-xinerama.so )
( cd usr/lib ; rm -rf libxcb-xfixes.so )
( cd usr/lib ; ln -sf libxcb-xfixes.so.0.0.0 libxcb-xfixes.so )
( cd usr/lib ; rm -rf libxcb.so )
( cd usr/lib ; ln -sf libxcb.so.1.1.0 libxcb.so )
( cd usr/lib ; rm -rf libxcb-dpms.so.0 )
( cd usr/lib ; ln -sf libxcb-dpms.so.0.0.0 libxcb-dpms.so.0 )
( cd usr/lib ; rm -rf libxcb-xvmc.so )
( cd usr/lib ; ln -sf libxcb-xvmc.so.0.0.0 libxcb-xvmc.so )
( cd usr/lib ; rm -rf libxcb-xlib.la )
( cd usr/lib ; ln -sf libxcb.la libxcb-xlib.la )
( cd usr/lib ; rm -rf libxcb-composite.so.0 )
( cd usr/lib ; ln -sf libxcb-composite.so.0.0.0 libxcb-composite.so.0 )
( cd usr/lib ; rm -rf libxcb-xtest.so.0 )
( cd usr/lib ; ln -sf libxcb-xtest.so.0.0.0 libxcb-xtest.so.0 )
( cd usr/lib ; rm -rf libxcb-xvmc.so.0 )
( cd usr/lib ; ln -sf libxcb-xvmc.so.0.0.0 libxcb-xvmc.so.0 )
( cd usr/lib ; rm -rf libxcb-sync.so )
( cd usr/lib ; ln -sf libxcb-sync.so.0.0.0 libxcb-sync.so )
( cd usr/lib ; rm -rf libxcb-render.so.0 )
( cd usr/lib ; ln -sf libxcb-render.so.0.0.0 libxcb-render.so.0 )
( cd usr/lib ; rm -rf libxcb-xlib.so )
( cd usr/lib ; ln -sf libxcb-xlib.so.0 libxcb-xlib.so )
( cd usr/lib ; rm -rf libxcb-xinerama.so.0 )
( cd usr/lib ; ln -sf libxcb-xinerama.so.0.0.0 libxcb-xinerama.so.0 )
( cd usr/lib ; rm -rf libxcb-randr.so )
( cd usr/lib ; ln -sf libxcb-randr.so.0.1.0 libxcb-randr.so )
( cd usr/lib ; rm -rf libxcb-xprint.so.0 )
( cd usr/lib ; ln -sf libxcb-xprint.so.0.0.0 libxcb-xprint.so.0 )
( cd usr/lib ; rm -rf libxcb-res.so.0 )
( cd usr/lib ; ln -sf libxcb-res.so.0.0.0 libxcb-res.so.0 )
( cd usr/lib ; rm -rf libxcb-screensaver.so.0 )
( cd usr/lib ; ln -sf libxcb-screensaver.so.0.0.0 libxcb-screensaver.so.0 )
( cd usr/lib ; rm -rf libxcb-glx.so )
( cd usr/lib ; ln -sf libxcb-glx.so.0.0.0 libxcb-glx.so )
( cd usr/lib ; rm -rf libxcb-damage.so )
( cd usr/lib ; ln -sf libxcb-damage.so.0.0.0 libxcb-damage.so )
( cd usr/lib ; rm -rf libxcb-dri2.so )
( cd usr/lib ; ln -sf libxcb-dri2.so.0.0.0 libxcb-dri2.so )
( cd usr/lib ; rm -rf libxcb-glx.so.0 )
( cd usr/lib ; ln -sf libxcb-glx.so.0.0.0 libxcb-glx.so.0 )
( cd usr/lib ; rm -rf libxcb-screensaver.so )
( cd usr/lib ; ln -sf libxcb-screensaver.so.0.0.0 libxcb-screensaver.so )
( cd usr/lib ; rm -rf libxcb-xprint.so )
( cd usr/lib ; ln -sf libxcb-xprint.so.0.0.0 libxcb-xprint.so )
( cd usr/lib ; rm -rf libxcb-xf86dri.so.0 )
( cd usr/lib ; ln -sf libxcb-xf86dri.so.0.0.0 libxcb-xf86dri.so.0 )
( cd usr/lib ; rm -rf libxcb-composite.so )
( cd usr/lib ; ln -sf libxcb-composite.so.0.0.0 libxcb-composite.so )
( cd usr/lib ; rm -rf libxcb-shape.so.0 )
( cd usr/lib ; ln -sf libxcb-shape.so.0.0.0 libxcb-shape.so.0 )
( cd usr/lib ; rm -rf libxcb-xf86dri.so )
( cd usr/lib ; ln -sf libxcb-xf86dri.so.0.0.0 libxcb-xf86dri.so )
( cd usr/lib ; rm -rf libxcb-dpms.so )
( cd usr/lib ; ln -sf libxcb-dpms.so.0.0.0 libxcb-dpms.so )
( cd usr/lib ; rm -rf libxcb-xtest.so )
( cd usr/lib ; ln -sf libxcb-xtest.so.0.0.0 libxcb-xtest.so )
( cd usr/lib ; rm -rf libxcb-xevie.so.0 )
( cd usr/lib ; ln -sf libxcb-xevie.so.0.0.0 libxcb-xevie.so.0 )
( cd usr/lib ; rm -rf libxcb-shm.so.0 )
( cd usr/lib ; ln -sf libxcb-shm.so.0.0.0 libxcb-shm.so.0 )
( cd usr/lib ; rm -rf libxcb-xfixes.so.0 )
( cd usr/lib ; ln -sf libxcb-xfixes.so.0.0.0 libxcb-xfixes.so.0 )
( cd usr/lib ; rm -rf libxcb-record.so.0 )
( cd usr/lib ; ln -sf libxcb-record.so.0.0.0 libxcb-record.so.0 )
( cd usr/lib ; rm -rf libxcb-res.so )
( cd usr/lib ; ln -sf libxcb-res.so.0.0.0 libxcb-res.so )
( cd usr/lib ; rm -rf libxcb-render.so )
( cd usr/lib ; ln -sf libxcb-render.so.0.0.0 libxcb-render.so )
# Package libxkbui-1.0.2-i486-2
( cd usr/lib ; rm -rf libxkbui.so.1 )
( cd usr/lib ; ln -sf libxkbui.so.1.0.0 libxkbui.so.1 )
( cd usr/lib ; rm -rf libxkbui.so )
( cd usr/lib ; ln -sf libxkbui.so.1.0.0 libxkbui.so )
# Package mesa-7.8.1-i486-1
( cd usr/lib ; rm -rf libEGL.so.1 )
( cd usr/lib ; ln -sf libEGL.so.1.0 libEGL.so.1 )
( cd usr/lib ; rm -rf libGLU.so )
( cd usr/lib ; ln -sf libGLU.so.1 libGLU.so )
( cd usr/lib ; rm -rf libGL.so.1 )
( cd usr/lib ; ln -sf libGL.so.1.2 libGL.so.1 )
( cd usr/lib ; rm -rf libGLw.so )
( cd usr/lib ; ln -sf libGLw.so.1 libGLw.so )
( cd usr/lib ; rm -rf libglut.so.3 )
( cd usr/lib ; ln -sf libglut.so.3.7.1 libglut.so.3 )
( cd usr/lib ; rm -rf libEGL.so )
( cd usr/lib ; ln -sf libEGL.so.1 libEGL.so )
( cd usr/lib ; rm -rf libGLw.so.1 )
( cd usr/lib ; ln -sf libGLw.so.1.0.0 libGLw.so.1 )
( cd usr/lib ; rm -rf libGLU.so.1 )
( cd usr/lib ; ln -sf libGLU.so.1.3.070801 libGLU.so.1 )
( cd usr/lib ; rm -rf libglut.so )
( cd usr/lib ; ln -sf libglut.so.3 libglut.so )
( cd usr/lib ; rm -rf libGL.so )
( cd usr/lib ; ln -sf libGL.so.1 libGL.so )
# Package pixman-0.16.6-i486-1
( cd usr/lib ; rm -rf libpixman-1.so.0 )
( cd usr/lib ; ln -sf libpixman-1.so.0.16.6 libpixman-1.so.0 )
( cd usr/lib ; rm -rf libpixman-1.so )
( cd usr/lib ; ln -sf libpixman-1.so.0.16.6 libpixman-1.so )
# Package fontconfig-2.8.0-i486-1
( cd usr/lib ; rm -rf libfontconfig.so.1 )
( cd usr/lib ; ln -sf libfontconfig.so.1.4.4 libfontconfig.so.1 )
( cd usr/lib ; rm -rf libfontconfig.so )
( cd usr/lib ; ln -sf libfontconfig.so.1.4.4 libfontconfig.so )
# Package glew-1.5.1-i486-1
( cd usr/lib ; rm -rf libGLEW.so )
( cd usr/lib ; ln -sf libGLEW.so.1.5.1 libGLEW.so )
( cd usr/lib ; rm -rf libGLEW.so.1.5 )
( cd usr/lib ; ln -sf libGLEW.so.1.5.1 libGLEW.so.1.5 )
# Package gd-2.0.35-i486-4
( cd usr/lib ; rm -rf libgd.so.2 )
( cd usr/lib ; ln -sf libgd.so.2.0.0 libgd.so.2 )
( cd usr/lib ; rm -rf libgd.so )
( cd usr/lib ; ln -sf libgd.so.2.0.0 libgd.so )
# Package libiodbc-3.52.7-i486-2
( cd usr/lib ; rm -rf libiodbc.so.2 )
( cd usr/lib ; ln -sf libiodbc.so.2.1.19 libiodbc.so.2 )
( cd usr/lib ; rm -rf libiodbcadm.so.2 )
( cd usr/lib ; ln -sf libiodbcadm.so.2.1.19 libiodbcadm.so.2 )
( cd usr/lib ; rm -rf libiodbcadm.so )
( cd usr/lib ; ln -sf libiodbcadm.so.2.1.19 libiodbcadm.so )
( cd usr/lib ; rm -rf libiodbcinst.so )
( cd usr/lib ; ln -sf libiodbcinst.so.2.1.19 libiodbcinst.so )
( cd usr/lib ; rm -rf libiodbc.so )
( cd usr/lib ; ln -sf libiodbc.so.2.1.19 libiodbc.so )
( cd usr/lib ; rm -rf libiodbcinst.so.2 )
( cd usr/lib ; ln -sf libiodbcinst.so.2.1.19 libiodbcinst.so.2 )
( cd usr/lib ; rm -rf libdrvproxy.so.2 )
( cd usr/lib ; ln -sf libdrvproxy.so.2.1.19 libdrvproxy.so.2 )
( cd usr/lib ; rm -rf libdrvproxy.so )
( cd usr/lib ; ln -sf libdrvproxy.so.2.1.19 libdrvproxy.so )
# Package libxkbfile-1.0.6-i486-1
( cd usr/lib ; rm -rf libxkbfile.so )
( cd usr/lib ; ln -sf libxkbfile.so.1.0.2 libxkbfile.so )
( cd usr/lib ; rm -rf libxkbfile.so.1 )
( cd usr/lib ; ln -sf libxkbfile.so.1.0.2 libxkbfile.so.1 )
# Package guile-1.8.7-i486-3
( cd usr/lib ; rm -rf libguile.so )
( cd usr/lib ; ln -sf libguile.so.17.3.1 libguile.so )
( cd usr/lib ; rm -rf libguile-srfi-srfi-13-14-v-3.so.3 )
( cd usr/lib ; ln -sf libguile-srfi-srfi-13-14-v-3.so.3.0.1 libguile-srfi-srfi-13-14-v-3.so.3 )
( cd usr/lib ; rm -rf libguile-srfi-srfi-60-v-2.so )
( cd usr/lib ; ln -sf libguile-srfi-srfi-60-v-2.so.2.0.2 libguile-srfi-srfi-60-v-2.so )
( cd usr/lib ; rm -rf libguilereadline-v-17.so.17 )
( cd usr/lib ; ln -sf libguilereadline-v-17.so.17.0.3 libguilereadline-v-17.so.17 )
( cd usr/lib ; rm -rf libguile.so.17 )
( cd usr/lib ; ln -sf libguile.so.17.3.1 libguile.so.17 )
( cd usr/lib ; rm -rf libguile-srfi-srfi-13-14-v-3.so )
( cd usr/lib ; ln -sf libguile-srfi-srfi-13-14-v-3.so.3.0.1 libguile-srfi-srfi-13-14-v-3.so )
( cd usr/lib ; rm -rf libguile-srfi-srfi-1-v-3.so.3 )
( cd usr/lib ; ln -sf libguile-srfi-srfi-1-v-3.so.3.0.2 libguile-srfi-srfi-1-v-3.so.3 )
( cd usr/lib ; rm -rf libguile-srfi-srfi-4-v-3.so.3 )
( cd usr/lib ; ln -sf libguile-srfi-srfi-4-v-3.so.3.0.1 libguile-srfi-srfi-4-v-3.so.3 )
( cd usr/lib ; rm -rf libguile-srfi-srfi-1-v-3.so )
( cd usr/lib ; ln -sf libguile-srfi-srfi-1-v-3.so.3.0.2 libguile-srfi-srfi-1-v-3.so )
( cd usr/lib ; rm -rf libguile-srfi-srfi-60-v-2.so.2 )
( cd usr/lib ; ln -sf libguile-srfi-srfi-60-v-2.so.2.0.2 libguile-srfi-srfi-60-v-2.so.2 )
( cd usr/lib ; rm -rf libguilereadline-v-17.so )
( cd usr/lib ; ln -sf libguilereadline-v-17.so.17.0.3 libguilereadline-v-17.so )
( cd usr/lib ; rm -rf libguile-srfi-srfi-4-v-3.so )
( cd usr/lib ; ln -sf libguile-srfi-srfi-4-v-3.so.3.0.1 libguile-srfi-srfi-4-v-3.so )
# Package python-2.6.4-i486-1
( cd usr/lib ; rm -rf libpython2.6.so )
( cd usr/lib ; ln -sf libpython2.6.so.1.0 libpython2.6.so )
